=== modified file 'Makefile.am'
--- Makefile.am	2008-07-28 07:17:35 +0000
+++ Makefile.am	2008-07-30 18:03:54 +0000
@@ -18,7 +18,6 @@
 SUBDIRS = . vio \
 	  mystrings \
 	  mysys \
-	  include \
 	  extra \
 	  libdrizzle \
 	  client \

=== modified file 'client/Makefile.am'
--- client/Makefile.am	2008-07-27 21:07:26 +0000
+++ client/Makefile.am	2008-07-30 18:03:54 +0000
@@ -18,7 +18,10 @@
 LDADD=				$(top_builddir)/libdrizzle/libdrizzle.la -lz
 
 
-noinst_HEADERS =	completion_hash.h my_readline.h client_priv.h
+noinst_HEADERS =	completion_hash.h \
+			my_readline.h \
+			client_priv.h \
+			errname.h
 
 CLEANFILES =		$(BUILT_SOURCES)
 

=== modified file 'client/drizzlecheck.c'
--- client/drizzlecheck.c	2008-07-29 21:59:54 +0000
+++ client/drizzlecheck.c	2008-07-30 18:03:54 +0000
@@ -19,7 +19,6 @@
 
 #include "client_priv.h"
 #include <mystrings/m_ctype.h>
-#include <drizzled_error.h>
 
 /* Exit codes */
 

=== modified file 'client/drizzledump.c'
--- client/drizzledump.c	2008-07-30 05:33:20 +0000
+++ client/drizzledump.c	2008-07-30 18:03:54 +0000
@@ -46,7 +46,7 @@
 #include <mysys/hash.h>
 #include <stdarg.h>
 
-#include "drizzled_error.h"
+#include <drizzled/error.h>
 
 /* Exit codes */
 

=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2008-07-30 03:40:13 +0000
+++ client/drizzletest.cc	2008-07-30 18:03:54 +0000
@@ -35,11 +35,11 @@
 #include <pcrecpp.h>
 
 #include "client_priv.h"
-#include <drizzled_error.h>
 #include <mysys/hash.h>
 #include <stdarg.h>
 #include <vio/violite.h>
 
+#include "errname.h"
 
 #define MAX_VAR_NAME_LENGTH    256
 #define MAX_COLUMNS            256
@@ -3325,20 +3325,6 @@
     abort_not_supported_test("Test requires charset '%s'", charset_name);
 }
 
-
-/* List of error names to error codes, available from 5.0 */
-typedef struct
-{
-  const char *name;
-  uint        code;
-} st_error;
-
-static st_error global_error_names[] =
-{
-#include <drizzled_ername.h>
-  { 0, 0 }
-};
-
 static uint get_errcode_from_name(char *error_name, char *error_end)
 {
   /* SQL error as string */

=== added file 'client/errname.h'
--- client/errname.h	1970-01-01 00:00:00 +0000
+++ client/errname.h	2008-07-30 18:03:54 +0000
@@ -0,0 +1,709 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 MySQL
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef _client_errname_h
+#define _client_errname_h
+
+/* List of error names to error codes, available from 5.0 */
+typedef struct
+{
+  const char *name;
+  uint        code;
+} st_error;
+
+static st_error global_error_names[]=
+{
+  { "ER_HASHCHK", 1000 },
+  { "ER_NISAMCHK", 1001 },
+  { "ER_NO", 1002 },
+  { "ER_YES", 1003 },
+  { "ER_CANT_CREATE_FILE", 1004 },
+  { "ER_CANT_CREATE_TABLE", 1005 },
+  { "ER_CANT_CREATE_DB", 1006 },
+  { "ER_DB_CREATE_EXISTS", 1007 },
+  { "ER_DB_DROP_EXISTS", 1008 },
+  { "ER_DB_DROP_DELETE", 1009 },
+  { "ER_DB_DROP_RMDIR", 1010 },
+  { "ER_CANT_DELETE_FILE", 1011 },
+  { "ER_CANT_FIND_SYSTEM_REC", 1012 },
+  { "ER_CANT_GET_STAT", 1013 },
+  { "ER_CANT_GET_WD", 1014 },
+  { "ER_CANT_LOCK", 1015 },
+  { "ER_CANT_OPEN_FILE", 1016 },
+  { "ER_FILE_NOT_FOUND", 1017 },
+  { "ER_CANT_READ_DIR", 1018 },
+  { "ER_CANT_SET_WD", 1019 },
+  { "ER_CHECKREAD", 1020 },
+  { "ER_DISK_FULL", 1021 },
+  { "ER_DUP_KEY", 1022 },
+  { "ER_ERROR_ON_CLOSE", 1023 },
+  { "ER_ERROR_ON_READ", 1024 },
+  { "ER_ERROR_ON_RENAME", 1025 },
+  { "ER_ERROR_ON_WRITE", 1026 },
+  { "ER_FILE_USED", 1027 },
+  { "ER_FILSORT_ABORT", 1028 },
+  { "ER_FORM_NOT_FOUND", 1029 },
+  { "ER_GET_ERRNO", 1030 },
+  { "ER_ILLEGAL_HA", 1031 },
+  { "ER_KEY_NOT_FOUND", 1032 },
+  { "ER_NOT_FORM_FILE", 1033 },
+  { "ER_NOT_KEYFILE", 1034 },
+  { "ER_OLD_KEYFILE", 1035 },
+  { "ER_OPEN_AS_READONLY", 1036 },
+  { "ER_OUTOFMEMORY", 1037 },
+  { "ER_OUT_OF_SORTMEMORY", 1038 },
+  { "ER_UNEXPECTED_EOF", 1039 },
+  { "ER_CON_COUNT_ERROR", 1040 },
+  { "ER_OUT_OF_RESOURCES", 1041 },
+  { "ER_BAD_HOST_ERROR", 1042 },
+  { "ER_HANDSHAKE_ERROR", 1043 },
+  { "ER_DBACCESS_DENIED_ERROR", 1044 },
+  { "ER_ACCESS_DENIED_ERROR", 1045 },
+  { "ER_NO_DB_ERROR", 1046 },
+  { "ER_UNKNOWN_COM_ERROR", 1047 },
+  { "ER_BAD_NULL_ERROR", 1048 },
+  { "ER_BAD_DB_ERROR", 1049 },
+  { "ER_TABLE_EXISTS_ERROR", 1050 },
+  { "ER_BAD_TABLE_ERROR", 1051 },
+  { "ER_NON_UNIQ_ERROR", 1052 },
+  { "ER_SERVER_SHUTDOWN", 1053 },
+  { "ER_BAD_FIELD_ERROR", 1054 },
+  { "ER_WRONG_FIELD_WITH_GROUP", 1055 },
+  { "ER_WRONG_GROUP_FIELD", 1056 },
+  { "ER_WRONG_SUM_SELECT", 1057 },
+  { "ER_WRONG_VALUE_COUNT", 1058 },
+  { "ER_TOO_LONG_IDENT", 1059 },
+  { "ER_DUP_FIELDNAME", 1060 },
+  { "ER_DUP_KEYNAME", 1061 },
+  { "ER_DUP_ENTRY", 1062 },
+  { "ER_WRONG_FIELD_SPEC", 1063 },
+  { "ER_PARSE_ERROR", 1064 },
+  { "ER_EMPTY_QUERY", 1065 },
+  { "ER_NONUNIQ_TABLE", 1066 },
+  { "ER_INVALID_DEFAULT", 1067 },
+  { "ER_MULTIPLE_PRI_KEY", 1068 },
+  { "ER_TOO_MANY_KEYS", 1069 },
+  { "ER_TOO_MANY_KEY_PARTS", 1070 },
+  { "ER_TOO_LONG_KEY", 1071 },
+  { "ER_KEY_COLUMN_DOES_NOT_EXITS", 1072 },
+  { "ER_BLOB_USED_AS_KEY", 1073 },
+  { "ER_TOO_BIG_FIELDLENGTH", 1074 },
+  { "ER_WRONG_AUTO_KEY", 1075 },
+  { "ER_READY", 1076 },
+  { "ER_NORMAL_SHUTDOWN", 1077 },
+  { "ER_GOT_SIGNAL", 1078 },
+  { "ER_SHUTDOWN_COMPLETE", 1079 },
+  { "ER_FORCING_CLOSE", 1080 },
+  { "ER_IPSOCK_ERROR", 1081 },
+  { "ER_NO_SUCH_INDEX", 1082 },
+  { "ER_WRONG_FIELD_TERMINATORS", 1083 },
+  { "ER_BLOBS_AND_NO_TERMINATED", 1084 },
+  { "ER_TEXTFILE_NOT_READABLE", 1085 },
+  { "ER_FILE_EXISTS_ERROR", 1086 },
+  { "ER_LOAD_INFO", 1087 },
+  { "ER_ALTER_INFO", 1088 },
+  { "ER_WRONG_SUB_KEY", 1089 },
+  { "ER_CANT_REMOVE_ALL_FIELDS", 1090 },
+  { "ER_CANT_DROP_FIELD_OR_KEY", 1091 },
+  { "ER_INSERT_INFO", 1092 },
+  { "ER_UPDATE_TABLE_USED", 1093 },
+  { "ER_NO_SUCH_THREAD", 1094 },
+  { "ER_KILL_DENIED_ERROR", 1095 },
+  { "ER_NO_TABLES_USED", 1096 },
+  { "ER_TOO_BIG_SET", 1097 },
+  { "ER_NO_UNIQUE_LOGFILE", 1098 },
+  { "ER_TABLE_NOT_LOCKED_FOR_WRITE", 1099 },
+  { "ER_TABLE_NOT_LOCKED", 1100 },
+  { "ER_BLOB_CANT_HAVE_DEFAULT", 1101 },
+  { "ER_WRONG_DB_NAME", 1102 },
+  { "ER_WRONG_TABLE_NAME", 1103 },
+  { "ER_TOO_BIG_SELECT", 1104 },
+  { "ER_UNKNOWN_ERROR", 1105 },
+  { "ER_UNKNOWN_PROCEDURE", 1106 },
+  { "ER_WRONG_PARAMCOUNT_TO_PROCEDURE", 1107 },
+  { "ER_WRONG_PARAMETERS_TO_PROCEDURE", 1108 },
+  { "ER_UNKNOWN_TABLE", 1109 },
+  { "ER_FIELD_SPECIFIED_TWICE", 1110 },
+  { "ER_INVALID_GROUP_FUNC_USE", 1111 },
+  { "ER_UNSUPPORTED_EXTENSION", 1112 },
+  { "ER_TABLE_MUST_HAVE_COLUMNS", 1113 },
+  { "ER_RECORD_FILE_FULL", 1114 },
+  { "ER_UNKNOWN_CHARACTER_SET", 1115 },
+  { "ER_TOO_MANY_TABLES", 1116 },
+  { "ER_TOO_MANY_FIELDS", 1117 },
+  { "ER_TOO_BIG_ROWSIZE", 1118 },
+  { "ER_STACK_OVERRUN", 1119 },
+  { "ER_WRONG_OUTER_JOIN", 1120 },
+  { "ER_NULL_COLUMN_IN_INDEX", 1121 },
+  { "ER_CANT_FIND_UDF", 1122 },
+  { "ER_CANT_INITIALIZE_UDF", 1123 },
+  { "ER_UDF_NO_PATHS", 1124 },
+  { "ER_UDF_EXISTS", 1125 },
+  { "ER_CANT_OPEN_LIBRARY", 1126 },
+  { "ER_CANT_FIND_DL_ENTRY", 1127 },
+  { "ER_FUNCTION_NOT_DEFINED", 1128 },
+  { "ER_HOST_IS_BLOCKED", 1129 },
+  { "ER_HOST_NOT_PRIVILEGED", 1130 },
+  { "ER_PASSWORD_ANONYMOUS_USER", 1131 },
+  { "ER_PASSWORD_NOT_ALLOWED", 1132 },
+  { "ER_PASSWORD_NO_MATCH", 1133 },
+  { "ER_UPDATE_INFO", 1134 },
+  { "ER_CANT_CREATE_THREAD", 1135 },
+  { "ER_WRONG_VALUE_COUNT_ON_ROW", 1136 },
+  { "ER_CANT_REOPEN_TABLE", 1137 },
+  { "ER_INVALID_USE_OF_NULL", 1138 },
+  { "ER_REGEXP_ERROR", 1139 },
+  { "ER_MIX_OF_GROUP_FUNC_AND_FIELDS", 1140 },
+  { "ER_NONEXISTING_GRANT", 1141 },
+  { "ER_TABLEACCESS_DENIED_ERROR", 1142 },
+  { "ER_COLUMNACCESS_DENIED_ERROR", 1143 },
+  { "ER_ILLEGAL_GRANT_FOR_TABLE", 1144 },
+  { "ER_GRANT_WRONG_HOST_OR_USER", 1145 },
+  { "ER_NO_SUCH_TABLE", 1146 },
+  { "ER_NONEXISTING_TABLE_GRANT", 1147 },
+  { "ER_NOT_ALLOWED_COMMAND", 1148 },
+  { "ER_SYNTAX_ERROR", 1149 },
+  { "ER_DELAYED_CANT_CHANGE_LOCK", 1150 },
+  { "ER_TOO_MANY_DELAYED_THREADS", 1151 },
+  { "ER_ABORTING_CONNECTION", 1152 },
+  { "ER_NET_PACKET_TOO_LARGE", 1153 },
+  { "ER_NET_READ_ERROR_FROM_PIPE", 1154 },
+  { "ER_NET_FCNTL_ERROR", 1155 },
+  { "ER_NET_PACKETS_OUT_OF_ORDER", 1156 },
+  { "ER_NET_UNCOMPRESS_ERROR", 1157 },
+  { "ER_NET_READ_ERROR", 1158 },
+  { "ER_NET_READ_INTERRUPTED", 1159 },
+  { "ER_NET_ERROR_ON_WRITE", 1160 },
+  { "ER_NET_WRITE_INTERRUPTED", 1161 },
+  { "ER_TOO_LONG_STRING", 1162 },
+  { "ER_TABLE_CANT_HANDLE_BLOB", 1163 },
+  { "ER_TABLE_CANT_HANDLE_AUTO_INCREMENT", 1164 },
+  { "ER_DELAYED_INSERT_TABLE_LOCKED", 1165 },
+  { "ER_WRONG_COLUMN_NAME", 1166 },
+  { "ER_WRONG_KEY_COLUMN", 1167 },
+  { "ER_WRONG_MRG_TABLE", 1168 },
+  { "ER_DUP_UNIQUE", 1169 },
+  { "ER_BLOB_KEY_WITHOUT_LENGTH", 1170 },
+  { "ER_PRIMARY_CANT_HAVE_NULL", 1171 },
+  { "ER_TOO_MANY_ROWS", 1172 },
+  { "ER_REQUIRES_PRIMARY_KEY", 1173 },
+  { "ER_NO_RAID_COMPILED", 1174 },
+  { "ER_UPDATE_WITHOUT_KEY_IN_SAFE_MODE", 1175 },
+  { "ER_KEY_DOES_NOT_EXITS", 1176 },
+  { "ER_CHECK_NO_SUCH_TABLE", 1177 },
+  { "ER_CHECK_NOT_IMPLEMENTED", 1178 },
+  { "ER_CANT_DO_THIS_DURING_AN_TRANSACTION", 1179 },
+  { "ER_ERROR_DURING_COMMIT", 1180 },
+  { "ER_ERROR_DURING_ROLLBACK", 1181 },
+  { "ER_ERROR_DURING_FLUSH_LOGS", 1182 },
+  { "ER_ERROR_DURING_CHECKPOINT", 1183 },
+  { "ER_NEW_ABORTING_CONNECTION", 1184 },
+  { "ER_DUMP_NOT_IMPLEMENTED", 1185 },
+  { "ER_FLUSH_MASTER_BINLOG_CLOSED", 1186 },
+  { "ER_INDEX_REBUILD", 1187 },
+  { "ER_MASTER", 1188 },
+  { "ER_MASTER_NET_READ", 1189 },
+  { "ER_MASTER_NET_WRITE", 1190 },
+  { "ER_FT_MATCHING_KEY_NOT_FOUND", 1191 },
+  { "ER_LOCK_OR_ACTIVE_TRANSACTION", 1192 },
+  { "ER_UNKNOWN_SYSTEM_VARIABLE", 1193 },
+  { "ER_CRASHED_ON_USAGE", 1194 },
+  { "ER_CRASHED_ON_REPAIR", 1195 },
+  { "ER_WARNING_NOT_COMPLETE_ROLLBACK", 1196 },
+  { "ER_TRANS_CACHE_FULL", 1197 },
+  { "ER_SLAVE_MUST_STOP", 1198 },
+  { "ER_SLAVE_NOT_RUNNING", 1199 },
+  { "ER_BAD_SLAVE", 1200 },
+  { "ER_MASTER_INFO", 1201 },
+  { "ER_SLAVE_THREAD", 1202 },
+  { "ER_TOO_MANY_USER_CONNECTIONS", 1203 },
+  { "ER_SET_CONSTANTS_ONLY", 1204 },
+  { "ER_LOCK_WAIT_TIMEOUT", 1205 },
+  { "ER_LOCK_TABLE_FULL", 1206 },
+  { "ER_READ_ONLY_TRANSACTION", 1207 },
+  { "ER_DROP_DB_WITH_READ_LOCK", 1208 },
+  { "ER_CREATE_DB_WITH_READ_LOCK", 1209 },
+  { "ER_WRONG_ARGUMENTS", 1210 },
+  { "ER_NO_PERMISSION_TO_CREATE_USER", 1211 },
+  { "ER_UNION_TABLES_IN_DIFFERENT_DIR", 1212 },
+  { "ER_LOCK_DEADLOCK", 1213 },
+  { "ER_TABLE_CANT_HANDLE_FT", 1214 },
+  { "ER_CANNOT_ADD_FOREIGN", 1215 },
+  { "ER_NO_REFERENCED_ROW", 1216 },
+  { "ER_ROW_IS_REFERENCED", 1217 },
+  { "ER_CONNECT_TO_MASTER", 1218 },
+  { "ER_QUERY_ON_MASTER", 1219 },
+  { "ER_ERROR_WHEN_EXECUTING_COMMAND", 1220 },
+  { "ER_WRONG_USAGE", 1221 },
+  { "ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT", 1222 },
+  { "ER_CANT_UPDATE_WITH_READLOCK", 1223 },
+  { "ER_MIXING_NOT_ALLOWED", 1224 },
+  { "ER_DUP_ARGUMENT", 1225 },
+  { "ER_USER_LIMIT_REACHED", 1226 },
+  { "ER_SPECIFIC_ACCESS_DENIED_ERROR", 1227 },
+  { "ER_LOCAL_VARIABLE", 1228 },
+  { "ER_GLOBAL_VARIABLE", 1229 },
+  { "ER_NO_DEFAULT", 1230 },
+  { "ER_WRONG_VALUE_FOR_VAR", 1231 },
+  { "ER_WRONG_TYPE_FOR_VAR", 1232 },
+  { "ER_VAR_CANT_BE_READ", 1233 },
+  { "ER_CANT_USE_OPTION_HERE", 1234 },
+  { "ER_NOT_SUPPORTED_YET", 1235 },
+  { "ER_MASTER_FATAL_ERROR_READING_BINLOG", 1236 },
+  { "ER_SLAVE_IGNORED_TABLE", 1237 },
+  { "ER_INCORRECT_GLOBAL_LOCAL_VAR", 1238 },
+  { "ER_WRONG_FK_DEF", 1239 },
+  { "ER_KEY_REF_DO_NOT_MATCH_TABLE_REF", 1240 },
+  { "ER_OPERAND_COLUMNS", 1241 },
+  { "ER_SUBQUERY_NO_1_ROW", 1242 },
+  { "ER_UNKNOWN_STMT_HANDLER", 1243 },
+  { "ER_CORRUPT_HELP_DB", 1244 },
+  { "ER_CYCLIC_REFERENCE", 1245 },
+  { "ER_AUTO_CONVERT", 1246 },
+  { "ER_ILLEGAL_REFERENCE", 1247 },
+  { "ER_DERIVED_MUST_HAVE_ALIAS", 1248 },
+  { "ER_SELECT_REDUCED", 1249 },
+  { "ER_TABLENAME_NOT_ALLOWED_HERE", 1250 },
+  { "ER_NOT_SUPPORTED_AUTH_MODE", 1251 },
+  { "ER_SPATIAL_CANT_HAVE_NULL", 1252 },
+  { "ER_COLLATION_CHARSET_MISMATCH", 1253 },
+  { "ER_SLAVE_WAS_RUNNING", 1254 },
+  { "ER_SLAVE_WAS_NOT_RUNNING", 1255 },
+  { "ER_TOO_BIG_FOR_UNCOMPRESS", 1256 },
+  { "ER_ZLIB_Z_MEM_ERROR", 1257 },
+  { "ER_ZLIB_Z_BUF_ERROR", 1258 },
+  { "ER_ZLIB_Z_DATA_ERROR", 1259 },
+  { "ER_CUT_VALUE_GROUP_CONCAT", 1260 },
+  { "ER_WARN_TOO_FEW_RECORDS", 1261 },
+  { "ER_WARN_TOO_MANY_RECORDS", 1262 },
+  { "ER_WARN_NULL_TO_NOTNULL", 1263 },
+  { "ER_WARN_DATA_OUT_OF_RANGE", 1264 },
+  { "WARN_DATA_TRUNCATED", 1265 },
+  { "ER_WARN_USING_OTHER_HANDLER", 1266 },
+  { "ER_CANT_AGGREGATE_2COLLATIONS", 1267 },
+  { "ER_DROP_USER", 1268 },
+  { "ER_REVOKE_GRANTS", 1269 },
+  { "ER_CANT_AGGREGATE_3COLLATIONS", 1270 },
+  { "ER_CANT_AGGREGATE_NCOLLATIONS", 1271 },
+  { "ER_VARIABLE_IS_NOT_STRUCT", 1272 },
+  { "ER_UNKNOWN_COLLATION", 1273 },
+  { "ER_SLAVE_IGNORED_SSL_PARAMS", 1274 },
+  { "ER_SERVER_IS_IN_SECURE_AUTH_MODE", 1275 },
+  { "ER_WARN_FIELD_RESOLVED", 1276 },
+  { "ER_BAD_SLAVE_UNTIL_COND", 1277 },
+  { "ER_MISSING_SKIP_SLAVE", 1278 },
+  { "ER_UNTIL_COND_IGNORED", 1279 },
+  { "ER_WRONG_NAME_FOR_INDEX", 1280 },
+  { "ER_WRONG_NAME_FOR_CATALOG", 1281 },
+  { "ER_WARN_QC_RESIZE", 1282 },
+  { "ER_BAD_FT_COLUMN", 1283 },
+  { "ER_UNKNOWN_KEY_CACHE", 1284 },
+  { "ER_WARN_HOSTNAME_WONT_WORK", 1285 },
+  { "ER_UNKNOWN_STORAGE_ENGINE", 1286 },
+  { "ER_WARN_DEPRECATED_SYNTAX", 1287 },
+  { "ER_NON_UPDATABLE_TABLE", 1288 },
+  { "ER_FEATURE_DISABLED", 1289 },
+  { "ER_OPTION_PREVENTS_STATEMENT", 1290 },
+  { "ER_DUPLICATED_VALUE_IN_TYPE", 1291 },
+  { "ER_TRUNCATED_WRONG_VALUE", 1292 },
+  { "ER_TOO_MUCH_AUTO_TIMESTAMP_COLS", 1293 },
+  { "ER_INVALID_ON_UPDATE", 1294 },
+  { "ER_UNSUPPORTED_PS", 1295 },
+  { "ER_GET_ERRMSG", 1296 },
+  { "ER_GET_TEMPORARY_ERRMSG", 1297 },
+  { "ER_UNKNOWN_TIME_ZONE", 1298 },
+  { "ER_WARN_INVALID_TIMESTAMP", 1299 },
+  { "ER_INVALID_CHARACTER_STRING", 1300 },
+  { "ER_WARN_ALLOWED_PACKET_OVERFLOWED", 1301 },
+  { "ER_CONFLICTING_DECLARATIONS", 1302 },
+  { "ER_SP_NO_RECURSIVE_CREATE", 1303 },
+  { "ER_SP_ALREADY_EXISTS", 1304 },
+  { "ER_SP_DOES_NOT_EXIST", 1305 },
+  { "ER_SP_DROP_FAILED", 1306 },
+  { "ER_SP_STORE_FAILED", 1307 },
+  { "ER_SP_LILABEL_MISMATCH", 1308 },
+  { "ER_SP_LABEL_REDEFINE", 1309 },
+  { "ER_SP_LABEL_MISMATCH", 1310 },
+  { "ER_SP_UNINIT_VAR", 1311 },
+  { "ER_SP_BADSELECT", 1312 },
+  { "ER_SP_BADRETURN", 1313 },
+  { "ER_SP_BADSTATEMENT", 1314 },
+  { "ER_UPDATE_LOG_DEPRECATED_IGNORED", 1315 },
+  { "ER_UPDATE_LOG_DEPRECATED_TRANSLATED", 1316 },
+  { "ER_QUERY_INTERRUPTED", 1317 },
+  { "ER_SP_WRONG_NO_OF_ARGS", 1318 },
+  { "ER_SP_COND_MISMATCH", 1319 },
+  { "ER_SP_NORETURN", 1320 },
+  { "ER_SP_NORETURNEND", 1321 },
+  { "ER_SP_BAD_CURSOR_QUERY", 1322 },
+  { "ER_SP_BAD_CURSOR_SELECT", 1323 },
+  { "ER_SP_CURSOR_MISMATCH", 1324 },
+  { "ER_SP_CURSOR_ALREADY_OPEN", 1325 },
+  { "ER_SP_CURSOR_NOT_OPEN", 1326 },
+  { "ER_SP_UNDECLARED_VAR", 1327 },
+  { "ER_SP_WRONG_NO_OF_FETCH_ARGS", 1328 },
+  { "ER_SP_FETCH_NO_DATA", 1329 },
+  { "ER_SP_DUP_PARAM", 1330 },
+  { "ER_SP_DUP_VAR", 1331 },
+  { "ER_SP_DUP_COND", 1332 },
+  { "ER_SP_DUP_CURS", 1333 },
+  { "ER_SP_CANT_ALTER", 1334 },
+  { "ER_SP_SUBSELECT_NYI", 1335 },
+  { "ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG", 1336 },
+  { "ER_SP_VARCOND_AFTER_CURSHNDLR", 1337 },
+  { "ER_SP_CURSOR_AFTER_HANDLER", 1338 },
+  { "ER_SP_CASE_NOT_FOUND", 1339 },
+  { "ER_FPARSER_TOO_BIG_FILE", 1340 },
+  { "ER_FPARSER_BAD_HEADER", 1341 },
+  { "ER_FPARSER_EOF_IN_COMMENT", 1342 },
+  { "ER_FPARSER_ERROR_IN_PARAMETER", 1343 },
+  { "ER_FPARSER_EOF_IN_UNKNOWN_PARAMETER", 1344 },
+  { "ER_VIEW_NO_EXPLAIN", 1345 },
+  { "ER_FRM_UNKNOWN_TYPE", 1346 },
+  { "ER_WRONG_OBJECT", 1347 },
+  { "ER_NONUPDATEABLE_COLUMN", 1348 },
+  { "ER_VIEW_SELECT_DERIVED", 1349 },
+  { "ER_VIEW_SELECT_CLAUSE", 1350 },
+  { "ER_VIEW_SELECT_VARIABLE", 1351 },
+  { "ER_VIEW_SELECT_TMPTABLE", 1352 },
+  { "ER_VIEW_WRONG_LIST", 1353 },
+  { "ER_WARN_VIEW_MERGE", 1354 },
+  { "ER_WARN_VIEW_WITHOUT_KEY", 1355 },
+  { "ER_VIEW_INVALID", 1356 },
+  { "ER_SP_NO_DROP_SP", 1357 },
+  { "ER_SP_GOTO_IN_HNDLR", 1358 },
+  { "ER_TRG_ALREADY_EXISTS", 1359 },
+  { "ER_TRG_DOES_NOT_EXIST", 1360 },
+  { "ER_TRG_ON_VIEW_OR_TEMP_TABLE", 1361 },
+  { "ER_TRG_CANT_CHANGE_ROW", 1362 },
+  { "ER_TRG_NO_SUCH_ROW_IN_TRG", 1363 },
+  { "ER_NO_DEFAULT_FOR_FIELD", 1364 },
+  { "ER_DIVISION_BY_ZERO", 1365 },
+  { "ER_TRUNCATED_WRONG_VALUE_FOR_FIELD", 1366 },
+  { "ER_ILLEGAL_VALUE_FOR_TYPE", 1367 },
+  { "ER_VIEW_NONUPD_CHECK", 1368 },
+  { "ER_VIEW_CHECK_FAILED", 1369 },
+  { "ER_PROCACCESS_DENIED_ERROR", 1370 },
+  { "ER_RELAY_LOG_FAIL", 1371 },
+  { "ER_PASSWD_LENGTH", 1372 },
+  { "ER_UNKNOWN_TARGET_BINLOG", 1373 },
+  { "ER_IO_ERR_LOG_INDEX_READ", 1374 },
+  { "ER_BINLOG_PURGE_PROHIBITED", 1375 },
+  { "ER_FSEEK_FAIL", 1376 },
+  { "ER_BINLOG_PURGE_FATAL_ERR", 1377 },
+  { "ER_LOG_IN_USE", 1378 },
+  { "ER_LOG_PURGE_UNKNOWN_ERR", 1379 },
+  { "ER_RELAY_LOG_INIT", 1380 },
+  { "ER_NO_BINARY_LOGGING", 1381 },
+  { "ER_RESERVED_SYNTAX", 1382 },
+  { "ER_WSAS_FAILED", 1383 },
+  { "ER_DIFF_GROUPS_PROC", 1384 },
+  { "ER_NO_GROUP_FOR_PROC", 1385 },
+  { "ER_ORDER_WITH_PROC", 1386 },
+  { "ER_LOGGING_PROHIBIT_CHANGING_OF", 1387 },
+  { "ER_NO_FILE_MAPPING", 1388 },
+  { "ER_WRONG_MAGIC", 1389 },
+  { "ER_PS_MANY_PARAM", 1390 },
+  { "ER_KEY_PART_0", 1391 },
+  { "ER_VIEW_CHECKSUM", 1392 },
+  { "ER_VIEW_MULTIUPDATE", 1393 },
+  { "ER_VIEW_NO_INSERT_FIELD_LIST", 1394 },
+  { "ER_VIEW_DELETE_MERGE_VIEW", 1395 },
+  { "ER_CANNOT_USER", 1396 },
+  { "ER_XAER_NOTA", 1397 },
+  { "ER_XAER_INVAL", 1398 },
+  { "ER_XAER_RMFAIL", 1399 },
+  { "ER_XAER_OUTSIDE", 1400 },
+  { "ER_XAER_RMERR", 1401 },
+  { "ER_XA_RBROLLBACK", 1402 },
+  { "ER_NONEXISTING_PROC_GRANT", 1403 },
+  { "ER_PROC_AUTO_GRANT_FAIL", 1404 },
+  { "ER_PROC_AUTO_REVOKE_FAIL", 1405 },
+  { "ER_DATA_TOO_LONG", 1406 },
+  { "ER_SP_BAD_SQLSTATE", 1407 },
+  { "ER_STARTUP", 1408 },
+  { "ER_LOAD_FROM_FIXED_SIZE_ROWS_TO_VAR", 1409 },
+  { "ER_CANT_CREATE_USER_WITH_GRANT", 1410 },
+  { "ER_WRONG_VALUE_FOR_TYPE", 1411 },
+  { "ER_TABLE_DEF_CHANGED", 1412 },
+  { "ER_SP_DUP_HANDLER", 1413 },
+  { "ER_SP_NOT_VAR_ARG", 1414 },
+  { "ER_SP_NO_RETSET", 1415 },
+  { "ER_CANT_CREATE_GEOMETRY_OBJECT", 1416 },
+  { "ER_FAILED_ROUTINE_BREAK_BINLOG", 1417 },
+  { "ER_BINLOG_UNSAFE_ROUTINE", 1418 },
+  { "ER_BINLOG_CREATE_ROUTINE_NEED_SUPER", 1419 },
+  { "ER_EXEC_STMT_WITH_OPEN_CURSOR", 1420 },
+  { "ER_STMT_HAS_NO_OPEN_CURSOR", 1421 },
+  { "ER_COMMIT_NOT_ALLOWED_IN_SF_OR_TRG", 1422 },
+  { "ER_NO_DEFAULT_FOR_VIEW_FIELD", 1423 },
+  { "ER_SP_NO_RECURSION", 1424 },
+  { "ER_TOO_BIG_SCALE", 1425 },
+  { "ER_TOO_BIG_PRECISION", 1426 },
+  { "ER_M_BIGGER_THAN_D", 1427 },
+  { "ER_WRONG_LOCK_OF_SYSTEM_TABLE", 1428 },
+  { "ER_CONNECT_TO_FOREIGN_DATA_SOURCE", 1429 },
+  { "ER_QUERY_ON_FOREIGN_DATA_SOURCE", 1430 },
+  { "ER_FOREIGN_DATA_SOURCE_DOESNT_EXIST", 1431 },
+  { "ER_FOREIGN_DATA_STRING_INVALID_CANT_CREATE", 1432 },
+  { "ER_FOREIGN_DATA_STRING_INVALID", 1433 },
+  { "ER_CANT_CREATE_FEDERATED_TABLE", 1434 },
+  { "ER_TRG_IN_WRONG_SCHEMA", 1435 },
+  { "ER_STACK_OVERRUN_NEED_MORE", 1436 },
+  { "ER_TOO_LONG_BODY", 1437 },
+  { "ER_WARN_CANT_DROP_DEFAULT_KEYCACHE", 1438 },
+  { "ER_TOO_BIG_DISPLAYWIDTH", 1439 },
+  { "ER_XAER_DUPID", 1440 },
+  { "ER_DATETIME_FUNCTION_OVERFLOW", 1441 },
+  { "ER_CANT_UPDATE_USED_TABLE_IN_SF_OR_TRG", 1442 },
+  { "ER_VIEW_PREVENT_UPDATE", 1443 },
+  { "ER_PS_NO_RECURSION", 1444 },
+  { "ER_SP_CANT_SET_AUTOCOMMIT", 1445 },
+  { "ER_MALFORMED_DEFINER", 1446 },
+  { "ER_VIEW_FRM_NO_USER", 1447 },
+  { "ER_VIEW_OTHER_USER", 1448 },
+  { "ER_NO_SUCH_USER", 1449 },
+  { "ER_FORBID_SCHEMA_CHANGE", 1450 },
+  { "ER_ROW_IS_REFERENCED_2", 1451 },
+  { "ER_NO_REFERENCED_ROW_2", 1452 },
+  { "ER_SP_BAD_VAR_SHADOW", 1453 },
+  { "ER_TRG_NO_DEFINER", 1454 },
+  { "ER_OLD_FILE_FORMAT", 1455 },
+  { "ER_SP_RECURSION_LIMIT", 1456 },
+  { "ER_SP_PROC_TABLE_CORRUPT", 1457 },
+  { "ER_SP_WRONG_NAME", 1458 },
+  { "ER_TABLE_NEEDS_UPGRADE", 1459 },
+  { "ER_SP_NO_AGGREGATE", 1460 },
+  { "ER_MAX_PREPARED_STMT_COUNT_REACHED", 1461 },
+  { "ER_VIEW_RECURSIVE", 1462 },
+  { "ER_NON_GROUPING_FIELD_USED", 1463 },
+  { "ER_TABLE_CANT_HANDLE_SPKEYS", 1464 },
+  { "ER_NO_TRIGGERS_ON_SYSTEM_SCHEMA", 1465 },
+  { "ER_REMOVED_SPACES", 1466 },
+  { "ER_AUTOINC_READ_FAILED", 1467 },
+  { "ER_USERNAME", 1468 },
+  { "ER_HOSTNAME", 1469 },
+  { "ER_WRONG_STRING_LENGTH", 1470 },
+  { "ER_NON_INSERTABLE_TABLE", 1471 },
+  { "ER_ADMIN_WRONG_MRG_TABLE", 1472 },
+  { "ER_TOO_HIGH_LEVEL_OF_NESTING_FOR_SELECT", 1473 },
+  { "ER_NAME_BECOMES_EMPTY", 1474 },
+  { "ER_AMBIGUOUS_FIELD_TERM", 1475 },
+  { "ER_FOREIGN_SERVER_EXISTS", 1476 },
+  { "ER_FOREIGN_SERVER_DOESNT_EXIST", 1477 },
+  { "ER_ILLEGAL_HA_CREATE_OPTION", 1478 },
+  { "ER_PARTITION_REQUIRES_VALUES_ERROR", 1479 },
+  { "ER_PARTITION_WRONG_VALUES_ERROR", 1480 },
+  { "ER_PARTITION_MAXVALUE_ERROR", 1481 },
+  { "ER_PARTITION_SUBPARTITION_ERROR", 1482 },
+  { "ER_PARTITION_SUBPART_MIX_ERROR", 1483 },
+  { "ER_PARTITION_WRONG_NO_PART_ERROR", 1484 },
+  { "ER_PARTITION_WRONG_NO_SUBPART_ERROR", 1485 },
+  { "ER_CONST_EXPR_IN_PARTITION_FUNC_ERROR", 1486 },
+  { "ER_NO_CONST_EXPR_IN_RANGE_OR_LIST_ERROR", 1487 },
+  { "ER_FIELD_NOT_FOUND_PART_ERROR", 1488 },
+  { "ER_LIST_OF_FIELDS_ONLY_IN_HASH_ERROR", 1489 },
+  { "ER_INCONSISTENT_PARTITION_INFO_ERROR", 1490 },
+  { "ER_PARTITION_FUNC_NOT_ALLOWED_ERROR", 1491 },
+  { "ER_PARTITIONS_MUST_BE_DEFINED_ERROR", 1492 },
+  { "ER_RANGE_NOT_INCREASING_ERROR", 1493 },
+  { "ER_INCONSISTENT_TYPE_OF_FUNCTIONS_ERROR", 1494 },
+  { "ER_MULTIPLE_DEF_CONST_IN_LIST_PART_ERROR", 1495 },
+  { "ER_PARTITION_ENTRY_ERROR", 1496 },
+  { "ER_MIX_HANDLER_ERROR", 1497 },
+  { "ER_PARTITION_NOT_DEFINED_ERROR", 1498 },
+  { "ER_TOO_MANY_PARTITIONS_ERROR", 1499 },
+  { "ER_SUBPARTITION_ERROR", 1500 },
+  { "ER_CANT_CREATE_HANDLER_FILE", 1501 },
+  { "ER_BLOB_FIELD_IN_PART_FUNC_ERROR", 1502 },
+  { "ER_UNIQUE_KEY_NEED_ALL_FIELDS_IN_PF", 1503 },
+  { "ER_NO_PARTS_ERROR", 1504 },
+  { "ER_PARTITION_MGMT_ON_NONPARTITIONED", 1505 },
+  { "ER_FOREIGN_KEY_ON_PARTITIONED", 1506 },
+  { "ER_DROP_PARTITION_NON_EXISTENT", 1507 },
+  { "ER_DROP_LAST_PARTITION", 1508 },
+  { "ER_COALESCE_ONLY_ON_HASH_PARTITION", 1509 },
+  { "ER_REORG_HASH_ONLY_ON_SAME_NO", 1510 },
+  { "ER_REORG_NO_PARAM_ERROR", 1511 },
+  { "ER_ONLY_ON_RANGE_LIST_PARTITION", 1512 },
+  { "ER_ADD_PARTITION_SUBPART_ERROR", 1513 },
+  { "ER_ADD_PARTITION_NO_NEW_PARTITION", 1514 },
+  { "ER_COALESCE_PARTITION_NO_PARTITION", 1515 },
+  { "ER_REORG_PARTITION_NOT_EXIST", 1516 },
+  { "ER_SAME_NAME_PARTITION", 1517 },
+  { "ER_NO_BINLOG_ERROR", 1518 },
+  { "ER_CONSECUTIVE_REORG_PARTITIONS", 1519 },
+  { "ER_REORG_OUTSIDE_RANGE", 1520 },
+  { "ER_PARTITION_FUNCTION_FAILURE", 1521 },
+  { "ER_PART_STATE_ERROR", 1522 },
+  { "ER_LIMITED_PART_RANGE", 1523 },
+  { "ER_PLUGIN_IS_NOT_LOADED", 1524 },
+  { "ER_WRONG_VALUE", 1525 },
+  { "ER_NO_PARTITION_FOR_GIVEN_VALUE", 1526 },
+  { "ER_FILEGROUP_OPTION_ONLY_ONCE", 1527 },
+  { "ER_CREATE_FILEGROUP_FAILED", 1528 },
+  { "ER_DROP_FILEGROUP_FAILED", 1529 },
+  { "ER_TABLESPACE_AUTO_EXTEND_ERROR", 1530 },
+  { "ER_WRONG_SIZE_NUMBER", 1531 },
+  { "ER_SIZE_OVERFLOW_ERROR", 1532 },
+  { "ER_ALTER_FILEGROUP_FAILED", 1533 },
+  { "ER_BINLOG_ROW_LOGGING_FAILED", 1534 },
+  { "ER_BINLOG_ROW_WRONG_TABLE_DEF", 1535 },
+  { "ER_BINLOG_ROW_RBR_TO_SBR", 1536 },
+  { "ER_EVENT_ALREADY_EXISTS", 1537 },
+  { "ER_EVENT_STORE_FAILED", 1538 },
+  { "ER_EVENT_DOES_NOT_EXIST", 1539 },
+  { "ER_EVENT_CANT_ALTER", 1540 },
+  { "ER_EVENT_DROP_FAILED", 1541 },
+  { "ER_EVENT_INTERVAL_NOT_POSITIVE_OR_TOO_BIG", 1542 },
+  { "ER_EVENT_ENDS_BEFORE_STARTS", 1543 },
+  { "ER_EVENT_EXEC_TIME_IN_THE_PAST", 1544 },
+  { "ER_EVENT_OPEN_TABLE_FAILED", 1545 },
+  { "ER_EVENT_NEITHER_M_EXPR_NOR_M_AT", 1546 },
+  { "ER_COL_COUNT_DOESNT_MATCH_CORRUPTED", 1547 },
+  { "ER_CANNOT_LOAD_FROM_TABLE", 1548 },
+  { "ER_EVENT_CANNOT_DELETE", 1549 },
+  { "ER_EVENT_COMPILE_ERROR", 1550 },
+  { "ER_EVENT_SAME_NAME", 1551 },
+  { "ER_EVENT_DATA_TOO_LONG", 1552 },
+  { "ER_DROP_INDEX_FK", 1553 },
+  { "ER_WARN_DEPRECATED_SYNTAX_WITH_VER", 1554 },
+  { "ER_CANT_WRITE_LOCK_LOG_TABLE", 1555 },
+  { "ER_CANT_LOCK_LOG_TABLE", 1556 },
+  { "ER_FOREIGN_DUPLICATE_KEY", 1557 },
+  { "ER_COL_COUNT_DOESNT_MATCH_PLEASE_UPDATE", 1558 },
+  { "ER_TEMP_TABLE_PREVENTS_SWITCH_OUT_OF_RBR", 1559 },
+  { "ER_STORED_FUNCTION_PREVENTS_SWITCH_BINLOG_FORMAT", 1560 },
+  { "ER_NDB_CANT_SWITCH_BINLOG_FORMAT", 1561 },
+  { "ER_PARTITION_NO_TEMPORARY", 1562 },
+  { "ER_PARTITION_CONST_DOMAIN_ERROR", 1563 },
+  { "ER_PARTITION_FUNCTION_IS_NOT_ALLOWED", 1564 },
+  { "ER_DDL_LOG_ERROR", 1565 },
+  { "ER_NULL_IN_VALUES_LESS_THAN", 1566 },
+  { "ER_WRONG_PARTITION_NAME", 1567 },
+  { "ER_CANT_CHANGE_TX_ISOLATION", 1568 },
+  { "ER_DUP_ENTRY_AUTOINCREMENT_CASE", 1569 },
+  { "ER_EVENT_MODIFY_QUEUE_ERROR", 1570 },
+  { "ER_EVENT_SET_VAR_ERROR", 1571 },
+  { "ER_PARTITION_MERGE_ERROR", 1572 },
+  { "ER_CANT_ACTIVATE_LOG", 1573 },
+  { "ER_RBR_NOT_AVAILABLE", 1574 },
+  { "ER_BASE64_DECODE_ERROR", 1575 },
+  { "ER_EVENT_RECURSION_FORBIDDEN", 1576 },
+  { "ER_EVENTS_DB_ERROR", 1577 },
+  { "ER_ONLY_INTEGERS_ALLOWED", 1578 },
+  { "ER_UNSUPORTED_LOG_ENGINE", 1579 },
+  { "ER_BAD_LOG_STATEMENT", 1580 },
+  { "ER_CANT_RENAME_LOG_TABLE", 1581 },
+  { "ER_WRONG_PARAMCOUNT_TO_NATIVE_FCT", 1582 },
+  { "ER_WRONG_PARAMETERS_TO_NATIVE_FCT", 1583 },
+  { "ER_WRONG_PARAMETERS_TO_STORED_FCT", 1584 },
+  { "ER_NATIVE_FCT_NAME_COLLISION", 1585 },
+  { "ER_DUP_ENTRY_WITH_KEY_NAME", 1586 },
+  { "ER_BINLOG_PURGE_EMFILE", 1587 },
+  { "ER_EVENT_CANNOT_CREATE_IN_THE_PAST", 1588 },
+  { "ER_EVENT_CANNOT_ALTER_IN_THE_PAST", 1589 },
+  { "ER_SLAVE_INCIDENT", 1590 },
+  { "ER_NO_PARTITION_FOR_GIVEN_VALUE_SILENT", 1591 },
+  { "ER_BINLOG_UNSAFE_STATEMENT", 1592 },
+  { "ER_SLAVE_FATAL_ERROR", 1593 },
+  { "ER_SLAVE_RELAY_LOG_READ_FAILURE", 1594 },
+  { "ER_SLAVE_RELAY_LOG_WRITE_FAILURE", 1595 },
+  { "ER_SLAVE_CREATE_EVENT_FAILURE", 1596 },
+  { "ER_SLAVE_MASTER_COM_FAILURE", 1597 },
+  { "ER_BINLOG_LOGGING_IMPOSSIBLE", 1598 },
+  { "ER_VIEW_NO_CREATION_CTX", 1599 },
+  { "ER_VIEW_INVALID_CREATION_CTX", 1600 },
+  { "ER_SR_INVALID_CREATION_CTX", 1601 },
+  { "ER_TRG_CORRUPTED_FILE", 1602 },
+  { "ER_TRG_NO_CREATION_CTX", 1603 },
+  { "ER_TRG_INVALID_CREATION_CTX", 1604 },
+  { "ER_EVENT_INVALID_CREATION_CTX", 1605 },
+  { "ER_TRG_CANT_OPEN_TABLE", 1606 },
+  { "ER_CANT_CREATE_SROUTINE", 1607 },
+  { "ER_SLAVE_AMBIGOUS_EXEC_MODE", 1608 },
+  { "ER_NO_FORMAT_DESCRIPTION_EVENT_BEFORE_BINLOG_STATEMENT", 1609 },
+  { "ER_SLAVE_CORRUPT_EVENT", 1610 },
+  { "ER_LOAD_DATA_INVALID_COLUMN", 1611 },
+  { "ER_LOG_PURGE_NO_FILE", 1612 },
+  { "ER_WARN_AUTO_CONVERT_LOCK", 1613 },
+  { "ER_NO_AUTO_CONVERT_LOCK_STRICT", 1614 },
+  { "ER_NO_AUTO_CONVERT_LOCK_TRANSACTION", 1615 },
+  { "ER_NO_STORAGE_ENGINE", 1616 },
+  { "ER_BACKUP_BACKUP_START", 1617 },
+  { "ER_BACKUP_BACKUP_DONE", 1618 },
+  { "ER_BACKUP_RESTORE_START", 1619 },
+  { "ER_BACKUP_RESTORE_DONE", 1620 },
+  { "ER_BACKUP_NOTHING_TO_BACKUP", 1621 },
+  { "ER_BACKUP_CANNOT_INCLUDE_DB", 1622 },
+  { "ER_BACKUP_BACKUP", 1623 },
+  { "ER_BACKUP_RESTORE", 1624 },
+  { "ER_BACKUP_RUNNING", 1625 },
+  { "ER_BACKUP_BACKUP_PREPARE", 1626 },
+  { "ER_BACKUP_RESTORE_PREPARE", 1627 },
+  { "ER_BACKUP_INVALID_LOC", 1628 },
+  { "ER_BACKUP_READ_LOC", 1629 },
+  { "ER_BACKUP_WRITE_LOC", 1630 },
+  { "ER_BACKUP_LIST_DBS", 1631 },
+  { "ER_BACKUP_LIST_TABLES", 1632 },
+  { "ER_BACKUP_LIST_DB_TABLES", 1633 },
+  { "ER_BACKUP_SKIP_VIEW", 1634 },
+  { "ER_BACKUP_NO_ENGINE", 1635 },
+  { "ER_BACKUP_TABLE_OPEN", 1636 },
+  { "ER_BACKUP_READ_HEADER", 1637 },
+  { "ER_BACKUP_WRITE_HEADER", 1638 },
+  { "ER_BACKUP_NO_BACKUP_DRIVER", 1639 },
+  { "ER_BACKUP_NOT_ACCEPTED", 1640 },
+  { "ER_BACKUP_CREATE_BACKUP_DRIVER", 1641 },
+  { "ER_BACKUP_CREATE_RESTORE_DRIVER", 1642 },
+  { "ER_BACKUP_TOO_MANY_IMAGES", 1643 },
+  { "ER_BACKUP_WRITE_META", 1644 },
+  { "ER_BACKUP_READ_META", 1645 },
+  { "ER_BACKUP_CREATE_META", 1646 },
+  { "ER_BACKUP_GET_BUF", 1647 },
+  { "ER_BACKUP_WRITE_DATA", 1648 },
+  { "ER_BACKUP_READ_DATA", 1649 },
+  { "ER_BACKUP_NEXT_CHUNK", 1650 },
+  { "ER_BACKUP_INIT_BACKUP_DRIVER", 1651 },
+  { "ER_BACKUP_INIT_RESTORE_DRIVER", 1652 },
+  { "ER_BACKUP_STOP_BACKUP_DRIVER", 1653 },
+  { "ER_BACKUP_STOP_RESTORE_DRIVERS", 1654 },
+  { "ER_BACKUP_PREPARE_DRIVER", 1655 },
+  { "ER_BACKUP_CREATE_VP", 1656 },
+  { "ER_BACKUP_UNLOCK_DRIVER", 1657 },
+  { "ER_BACKUP_CANCEL_BACKUP", 1658 },
+  { "ER_BACKUP_CANCEL_RESTORE", 1659 },
+  { "ER_BACKUP_GET_DATA", 1660 },
+  { "ER_BACKUP_SEND_DATA", 1661 },
+  { "ER_BACKUP_SEND_DATA_RETRY", 1662 },
+  { "ER_BACKUP_OPEN_TABLES", 1663 },
+  { "ER_BACKUP_THREAD_INIT", 1664 },
+  { "ER_BACKUP_PROGRESS_TABLES", 1665 },
+  { "ER_TABLESPACE_EXIST", 1666 },
+  { "ER_NO_SUCH_TABLESPACE", 1667 },
+  { "ER_SLAVE_HEARTBEAT_FAILURE", 1668 },
+  { "ER_SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE", 1669 },
+  { "ER_BACKUP_LOG_WRITE_ERROR", 1670 },
+  { "ER_TABLESPACE_NOT_EMPTY", 1671 },
+  { "ER_BACKUP_TS_CHANGE", 1672 },
+  { 0, 0 }
+};
+
+#endif

=== modified file 'client/mysqlslap.c'
--- client/mysqlslap.c	2008-07-30 03:40:13 +0000
+++ client/mysqlslap.c	2008-07-30 18:03:54 +0000
@@ -76,7 +76,6 @@
 #define DEFAULT_BLOB_SIZE 1024
 
 #include "client_priv.h"
-#include <drizzled_error.h>
 #include <signal.h>
 #include <stdarg.h>
 #include <sys/types.h>

=== modified file 'configure.ac'
--- configure.ac	2008-07-30 05:37:06 +0000
+++ configure.ac	2008-07-30 18:03:54 +0000
@@ -1292,7 +1292,6 @@
  drizzled/field/Makefile dnl
  drizzled/share/Makefile dnl
  drizzled/sql_builtin.cc dnl
- include/Makefile dnl
  support-files/Makefile dnl
  tests/Makefile tests/install_test_db dnl
  drizzled/version.h plugin/Makefile dnl

=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2008-07-30 05:33:20 +0000
+++ drizzled/Makefile.am	2008-07-30 18:03:54 +0000
@@ -47,7 +47,8 @@
 	      sql_select.o \
 	      sql_update.o
 
-pkginclude_HEADERS =	plugin.h \
+pkginclude_HEADERS =	error.h \
+			plugin.h \
 			plugin_audit.h
 
 noinst_LTLIBRARIES = libhandler.la
@@ -87,6 +88,7 @@
 		 sql_lex.h \
 		 sql_list.h \
 		 sql_map.h \
+		 sql_state.h \
 		 sql_string.h \
 		 unireg.h \
 		 sql_error.h \

=== added file 'drizzled/error.h'
--- drizzled/error.h	1970-01-01 00:00:00 +0000
+++ drizzled/error.h	2008-07-30 18:03:54 +0000
@@ -0,0 +1,703 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 MySQL
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef _drizzled_error_h
+#define _drizzled_error_h
+
+enum drizzled_error_code {
+  ER_ERROR_FIRST= 1000,
+  ER_HASHCHK= 1000,
+  ER_NISAMCHK,
+  ER_NO,
+  ER_YES,
+  ER_CANT_CREATE_FILE,
+  ER_CANT_CREATE_TABLE,
+  ER_CANT_CREATE_DB,
+  ER_DB_CREATE_EXISTS,
+  ER_DB_DROP_EXISTS,
+  ER_DB_DROP_DELETE,
+  ER_DB_DROP_RMDIR,
+  ER_CANT_DELETE_FILE,
+  ER_CANT_FIND_SYSTEM_REC,
+  ER_CANT_GET_STAT,
+  ER_CANT_GET_WD,
+  ER_CANT_LOCK,
+  ER_CANT_OPEN_FILE,
+  ER_FILE_NOT_FOUND,
+  ER_CANT_READ_DIR,
+  ER_CANT_SET_WD,
+  ER_CHECKREAD,
+  ER_DISK_FULL,
+  ER_DUP_KEY,
+  ER_ERROR_ON_CLOSE,
+  ER_ERROR_ON_READ,
+  ER_ERROR_ON_RENAME,
+  ER_ERROR_ON_WRITE,
+  ER_FILE_USED,
+  ER_FILSORT_ABORT,
+  ER_FORM_NOT_FOUND,
+  ER_GET_ERRNO,
+  ER_ILLEGAL_HA,
+  ER_KEY_NOT_FOUND,
+  ER_NOT_FORM_FILE,
+  ER_NOT_KEYFILE,
+  ER_OLD_KEYFILE,
+  ER_OPEN_AS_READONLY,
+  ER_OUTOFMEMORY,
+  ER_OUT_OF_SORTMEMORY,
+  ER_UNEXPECTED_EOF,
+  ER_CON_COUNT_ERROR,
+  ER_OUT_OF_RESOURCES,
+  ER_BAD_HOST_ERROR,
+  ER_HANDSHAKE_ERROR,
+  ER_DBACCESS_DENIED_ERROR,
+  ER_ACCESS_DENIED_ERROR,
+  ER_NO_DB_ERROR,
+  ER_UNKNOWN_COM_ERROR,
+  ER_BAD_NULL_ERROR,
+  ER_BAD_DB_ERROR,
+  ER_TABLE_EXISTS_ERROR,
+  ER_BAD_TABLE_ERROR,
+  ER_NON_UNIQ_ERROR,
+  ER_SERVER_SHUTDOWN,
+  ER_BAD_FIELD_ERROR,
+  ER_WRONG_FIELD_WITH_GROUP,
+  ER_WRONG_GROUP_FIELD,
+  ER_WRONG_SUM_SELECT,
+  ER_WRONG_VALUE_COUNT,
+  ER_TOO_LONG_IDENT,
+  ER_DUP_FIELDNAME,
+  ER_DUP_KEYNAME,
+  ER_DUP_ENTRY,
+  ER_WRONG_FIELD_SPEC,
+  ER_PARSE_ERROR,
+  ER_EMPTY_QUERY,
+  ER_NONUNIQ_TABLE,
+  ER_INVALID_DEFAULT,
+  ER_MULTIPLE_PRI_KEY,
+  ER_TOO_MANY_KEYS,
+  ER_TOO_MANY_KEY_PARTS,
+  ER_TOO_LONG_KEY,
+  ER_KEY_COLUMN_DOES_NOT_EXITS,
+  ER_BLOB_USED_AS_KEY,
+  ER_TOO_BIG_FIELDLENGTH,
+  ER_WRONG_AUTO_KEY,
+  ER_READY,
+  ER_NORMAL_SHUTDOWN,
+  ER_GOT_SIGNAL,
+  ER_SHUTDOWN_COMPLETE,
+  ER_FORCING_CLOSE,
+  ER_IPSOCK_ERROR,
+  ER_NO_SUCH_INDEX,
+  ER_WRONG_FIELD_TERMINATORS,
+  ER_BLOBS_AND_NO_TERMINATED,
+  ER_TEXTFILE_NOT_READABLE,
+  ER_FILE_EXISTS_ERROR,
+  ER_LOAD_INFO,
+  ER_ALTER_INFO,
+  ER_WRONG_SUB_KEY,
+  ER_CANT_REMOVE_ALL_FIELDS,
+  ER_CANT_DROP_FIELD_OR_KEY,
+  ER_INSERT_INFO,
+  ER_UPDATE_TABLE_USED,
+  ER_NO_SUCH_THREAD,
+  ER_KILL_DENIED_ERROR,
+  ER_NO_TABLES_USED,
+  ER_TOO_BIG_SET,
+  ER_NO_UNIQUE_LOGFILE,
+  ER_TABLE_NOT_LOCKED_FOR_WRITE,
+  ER_TABLE_NOT_LOCKED,
+  ER_BLOB_CANT_HAVE_DEFAULT,
+  ER_WRONG_DB_NAME,
+  ER_WRONG_TABLE_NAME,
+  ER_TOO_BIG_SELECT,
+  ER_UNKNOWN_ERROR,
+  ER_UNKNOWN_PROCEDURE,
+  ER_WRONG_PARAMCOUNT_TO_PROCEDURE,
+  ER_WRONG_PARAMETERS_TO_PROCEDURE,
+  ER_UNKNOWN_TABLE,
+  ER_FIELD_SPECIFIED_TWICE,
+  ER_INVALID_GROUP_FUNC_USE,
+  ER_UNSUPPORTED_EXTENSION,
+  ER_TABLE_MUST_HAVE_COLUMNS,
+  ER_RECORD_FILE_FULL,
+  ER_UNKNOWN_CHARACTER_SET,
+  ER_TOO_MANY_TABLES,
+  ER_TOO_MANY_FIELDS,
+  ER_TOO_BIG_ROWSIZE,
+  ER_STACK_OVERRUN,
+  ER_WRONG_OUTER_JOIN,
+  ER_NULL_COLUMN_IN_INDEX,
+  ER_CANT_FIND_UDF,
+  ER_CANT_INITIALIZE_UDF,
+  ER_UDF_NO_PATHS,
+  ER_UDF_EXISTS,
+  ER_CANT_OPEN_LIBRARY,
+  ER_CANT_FIND_DL_ENTRY,
+  ER_FUNCTION_NOT_DEFINED,
+  ER_HOST_IS_BLOCKED,
+  ER_HOST_NOT_PRIVILEGED,
+  ER_PASSWORD_ANONYMOUS_USER,
+  ER_PASSWORD_NOT_ALLOWED,
+  ER_PASSWORD_NO_MATCH,
+  ER_UPDATE_INFO,
+  ER_CANT_CREATE_THREAD,
+  ER_WRONG_VALUE_COUNT_ON_ROW,
+  ER_CANT_REOPEN_TABLE,
+  ER_INVALID_USE_OF_NULL,
+  ER_REGEXP_ERROR,
+  ER_MIX_OF_GROUP_FUNC_AND_FIELDS,
+  ER_NONEXISTING_GRANT,
+  ER_TABLEACCESS_DENIED_ERROR,
+  ER_COLUMNACCESS_DENIED_ERROR,
+  ER_ILLEGAL_GRANT_FOR_TABLE,
+  ER_GRANT_WRONG_HOST_OR_USER,
+  ER_NO_SUCH_TABLE,
+  ER_NONEXISTING_TABLE_GRANT,
+  ER_NOT_ALLOWED_COMMAND,
+  ER_SYNTAX_ERROR,
+  ER_DELAYED_CANT_CHANGE_LOCK,
+  ER_TOO_MANY_DELAYED_THREADS,
+  ER_ABORTING_CONNECTION,
+  ER_NET_PACKET_TOO_LARGE,
+  ER_NET_READ_ERROR_FROM_PIPE,
+  ER_NET_FCNTL_ERROR,
+  ER_NET_PACKETS_OUT_OF_ORDER,
+  ER_NET_UNCOMPRESS_ERROR,
+  ER_NET_READ_ERROR,
+  ER_NET_READ_INTERRUPTED,
+  ER_NET_ERROR_ON_WRITE,
+  ER_NET_WRITE_INTERRUPTED,
+  ER_TOO_LONG_STRING,
+  ER_TABLE_CANT_HANDLE_BLOB,
+  ER_TABLE_CANT_HANDLE_AUTO_INCREMENT,
+  ER_DELAYED_INSERT_TABLE_LOCKED,
+  ER_WRONG_COLUMN_NAME,
+  ER_WRONG_KEY_COLUMN,
+  ER_WRONG_MRG_TABLE,
+  ER_DUP_UNIQUE,
+  ER_BLOB_KEY_WITHOUT_LENGTH,
+  ER_PRIMARY_CANT_HAVE_NULL,
+  ER_TOO_MANY_ROWS,
+  ER_REQUIRES_PRIMARY_KEY,
+  ER_NO_RAID_COMPILED,
+  ER_UPDATE_WITHOUT_KEY_IN_SAFE_MODE,
+  ER_KEY_DOES_NOT_EXITS,
+  ER_CHECK_NO_SUCH_TABLE,
+  ER_CHECK_NOT_IMPLEMENTED,
+  ER_CANT_DO_THIS_DURING_AN_TRANSACTION,
+  ER_ERROR_DURING_COMMIT,
+  ER_ERROR_DURING_ROLLBACK,
+  ER_ERROR_DURING_FLUSH_LOGS,
+  ER_ERROR_DURING_CHECKPOINT,
+  ER_NEW_ABORTING_CONNECTION,
+  ER_DUMP_NOT_IMPLEMENTED,
+  ER_FLUSH_MASTER_BINLOG_CLOSED,
+  ER_INDEX_REBUILD,
+  ER_MASTER,
+  ER_MASTER_NET_READ,
+  ER_MASTER_NET_WRITE,
+  ER_FT_MATCHING_KEY_NOT_FOUND,
+  ER_LOCK_OR_ACTIVE_TRANSACTION,
+  ER_UNKNOWN_SYSTEM_VARIABLE,
+  ER_CRASHED_ON_USAGE,
+  ER_CRASHED_ON_REPAIR,
+  ER_WARNING_NOT_COMPLETE_ROLLBACK,
+  ER_TRANS_CACHE_FULL,
+  ER_SLAVE_MUST_STOP,
+  ER_SLAVE_NOT_RUNNING,
+  ER_BAD_SLAVE,
+  ER_MASTER_INFO,
+  ER_SLAVE_THREAD,
+  ER_TOO_MANY_USER_CONNECTIONS,
+  ER_SET_CONSTANTS_ONLY,
+  ER_LOCK_WAIT_TIMEOUT,
+  ER_LOCK_TABLE_FULL,
+  ER_READ_ONLY_TRANSACTION,
+  ER_DROP_DB_WITH_READ_LOCK,
+  ER_CREATE_DB_WITH_READ_LOCK,
+  ER_WRONG_ARGUMENTS,
+  ER_NO_PERMISSION_TO_CREATE_USER,
+  ER_UNION_TABLES_IN_DIFFERENT_DIR,
+  ER_LOCK_DEADLOCK,
+  ER_TABLE_CANT_HANDLE_FT,
+  ER_CANNOT_ADD_FOREIGN,
+  ER_NO_REFERENCED_ROW,
+  ER_ROW_IS_REFERENCED,
+  ER_CONNECT_TO_MASTER,
+  ER_QUERY_ON_MASTER,
+  ER_ERROR_WHEN_EXECUTING_COMMAND,
+  ER_WRONG_USAGE,
+  ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT,
+  ER_CANT_UPDATE_WITH_READLOCK,
+  ER_MIXING_NOT_ALLOWED,
+  ER_DUP_ARGUMENT,
+  ER_USER_LIMIT_REACHED,
+  ER_SPECIFIC_ACCESS_DENIED_ERROR,
+  ER_LOCAL_VARIABLE,
+  ER_GLOBAL_VARIABLE,
+  ER_NO_DEFAULT,
+  ER_WRONG_VALUE_FOR_VAR,
+  ER_WRONG_TYPE_FOR_VAR,
+  ER_VAR_CANT_BE_READ,
+  ER_CANT_USE_OPTION_HERE,
+  ER_NOT_SUPPORTED_YET,
+  ER_MASTER_FATAL_ERROR_READING_BINLOG,
+  ER_SLAVE_IGNORED_TABLE,
+  ER_INCORRECT_GLOBAL_LOCAL_VAR,
+  ER_WRONG_FK_DEF,
+  ER_KEY_REF_DO_NOT_MATCH_TABLE_REF,
+  ER_OPERAND_COLUMNS,
+  ER_SUBQUERY_NO_1_ROW,
+  ER_UNKNOWN_STMT_HANDLER,
+  ER_CORRUPT_HELP_DB,
+  ER_CYCLIC_REFERENCE,
+  ER_AUTO_CONVERT,
+  ER_ILLEGAL_REFERENCE,
+  ER_DERIVED_MUST_HAVE_ALIAS,
+  ER_SELECT_REDUCED,
+  ER_TABLENAME_NOT_ALLOWED_HERE,
+  ER_NOT_SUPPORTED_AUTH_MODE,
+  ER_SPATIAL_CANT_HAVE_NULL,
+  ER_COLLATION_CHARSET_MISMATCH,
+  ER_SLAVE_WAS_RUNNING,
+  ER_SLAVE_WAS_NOT_RUNNING,
+  ER_TOO_BIG_FOR_UNCOMPRESS,
+  ER_ZLIB_Z_MEM_ERROR,
+  ER_ZLIB_Z_BUF_ERROR,
+  ER_ZLIB_Z_DATA_ERROR,
+  ER_CUT_VALUE_GROUP_CONCAT,
+  ER_WARN_TOO_FEW_RECORDS,
+  ER_WARN_TOO_MANY_RECORDS,
+  ER_WARN_NULL_TO_NOTNULL,
+  ER_WARN_DATA_OUT_OF_RANGE,
+  ER_WARN_DATA_TRUNCATED,
+  ER_WARN_USING_OTHER_HANDLER,
+  ER_CANT_AGGREGATE_2COLLATIONS,
+  ER_DROP_USER,
+  ER_REVOKE_GRANTS,
+  ER_CANT_AGGREGATE_3COLLATIONS,
+  ER_CANT_AGGREGATE_NCOLLATIONS,
+  ER_VARIABLE_IS_NOT_STRUCT,
+  ER_UNKNOWN_COLLATION,
+  ER_SLAVE_IGNORED_SSL_PARAMS,
+  ER_SERVER_IS_IN_SECURE_AUTH_MODE,
+  ER_WARN_FIELD_RESOLVED,
+  ER_BAD_SLAVE_UNTIL_COND,
+  ER_MISSING_SKIP_SLAVE,
+  ER_UNTIL_COND_IGNORED,
+  ER_WRONG_NAME_FOR_INDEX,
+  ER_WRONG_NAME_FOR_CATALOG,
+  ER_WARN_QC_RESIZE,
+  ER_BAD_FT_COLUMN,
+  ER_UNKNOWN_KEY_CACHE,
+  ER_WARN_HOSTNAME_WONT_WORK,
+  ER_UNKNOWN_STORAGE_ENGINE,
+  ER_WARN_DEPRECATED_SYNTAX,
+  ER_NON_UPDATABLE_TABLE,
+  ER_FEATURE_DISABLED,
+  ER_OPTION_PREVENTS_STATEMENT,
+  ER_DUPLICATED_VALUE_IN_TYPE,
+  ER_TRUNCATED_WRONG_VALUE,
+  ER_TOO_MUCH_AUTO_TIMESTAMP_COLS,
+  ER_INVALID_ON_UPDATE,
+  ER_UNSUPPORTED_PS,
+  ER_GET_ERRMSG,
+  ER_GET_TEMPORARY_ERRMSG,
+  ER_UNKNOWN_TIME_ZONE,
+  ER_WARN_INVALID_TIMESTAMP,
+  ER_INVALID_CHARACTER_STRING,
+  ER_WARN_ALLOWED_PACKET_OVERFLOWED,
+  ER_CONFLICTING_DECLARATIONS,
+  ER_SP_NO_RECURSIVE_CREATE,
+  ER_SP_ALREADY_EXISTS,
+  ER_SP_DOES_NOT_EXIST,
+  ER_SP_DROP_FAILED,
+  ER_SP_STORE_FAILED,
+  ER_SP_LILABEL_MISMATCH,
+  ER_SP_LABEL_REDEFINE,
+  ER_SP_LABEL_MISMATCH,
+  ER_SP_UNINIT_VAR,
+  ER_SP_BADSELECT,
+  ER_SP_BADRETURN,
+  ER_SP_BADSTATEMENT,
+  ER_UPDATE_LOG_DEPRECATED_IGNORED,
+  ER_UPDATE_LOG_DEPRECATED_TRANSLATED,
+  ER_QUERY_INTERRUPTED,
+  ER_SP_WRONG_NO_OF_ARGS,
+  ER_SP_COND_MISMATCH,
+  ER_SP_NORETURN,
+  ER_SP_NORETURNEND,
+  ER_SP_BAD_CURSOR_QUERY,
+  ER_SP_BAD_CURSOR_SELECT,
+  ER_SP_CURSOR_MISMATCH,
+  ER_SP_CURSOR_ALREADY_OPEN,
+  ER_SP_CURSOR_NOT_OPEN,
+  ER_SP_UNDECLARED_VAR,
+  ER_SP_WRONG_NO_OF_FETCH_ARGS,
+  ER_SP_FETCH_NO_DATA,
+  ER_SP_DUP_PARAM,
+  ER_SP_DUP_VAR,
+  ER_SP_DUP_COND,
+  ER_SP_DUP_CURS,
+  ER_SP_CANT_ALTER,
+  ER_SP_SUBSELECT_NYI,
+  ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG,
+  ER_SP_VARCOND_AFTER_CURSHNDLR,
+  ER_SP_CURSOR_AFTER_HANDLER,
+  ER_SP_CASE_NOT_FOUND,
+  ER_FPARSER_TOO_BIG_FILE,
+  ER_FPARSER_BAD_HEADER,
+  ER_FPARSER_EOF_IN_COMMENT,
+  ER_FPARSER_ERROR_IN_PARAMETER,
+  ER_FPARSER_EOF_IN_UNKNOWN_PARAMETER,
+  ER_VIEW_NO_EXPLAIN,
+  ER_FRM_UNKNOWN_TYPE,
+  ER_WRONG_OBJECT,
+  ER_NONUPDATEABLE_COLUMN,
+  ER_VIEW_SELECT_DERIVED,
+  ER_VIEW_SELECT_CLAUSE,
+  ER_VIEW_SELECT_VARIABLE,
+  ER_VIEW_SELECT_TMPTABLE,
+  ER_VIEW_WRONG_LIST,
+  ER_WARN_VIEW_MERGE,
+  ER_WARN_VIEW_WITHOUT_KEY,
+  ER_VIEW_INVALID,
+  ER_SP_NO_DROP_SP,
+  ER_SP_GOTO_IN_HNDLR,
+  ER_TRG_ALREADY_EXISTS,
+  ER_TRG_DOES_NOT_EXIST,
+  ER_TRG_ON_VIEW_OR_TEMP_TABLE,
+  ER_TRG_CANT_CHANGE_ROW,
+  ER_TRG_NO_SUCH_ROW_IN_TRG,
+  ER_NO_DEFAULT_FOR_FIELD,
+  ER_DIVISION_BY_ZERO,
+  ER_TRUNCATED_WRONG_VALUE_FOR_FIELD,
+  ER_ILLEGAL_VALUE_FOR_TYPE,
+  ER_VIEW_NONUPD_CHECK,
+  ER_VIEW_CHECK_FAILED,
+  ER_PROCACCESS_DENIED_ERROR,
+  ER_RELAY_LOG_FAIL,
+  ER_PASSWD_LENGTH,
+  ER_UNKNOWN_TARGET_BINLOG,
+  ER_IO_ERR_LOG_INDEX_READ,
+  ER_BINLOG_PURGE_PROHIBITED,
+  ER_FSEEK_FAIL,
+  ER_BINLOG_PURGE_FATAL_ERR,
+  ER_LOG_IN_USE,
+  ER_LOG_PURGE_UNKNOWN_ERR,
+  ER_RELAY_LOG_INIT,
+  ER_NO_BINARY_LOGGING,
+  ER_RESERVED_SYNTAX,
+  ER_WSAS_FAILED,
+  ER_DIFF_GROUPS_PROC,
+  ER_NO_GROUP_FOR_PROC,
+  ER_ORDER_WITH_PROC,
+  ER_LOGGING_PROHIBIT_CHANGING_OF,
+  ER_NO_FILE_MAPPING,
+  ER_WRONG_MAGIC,
+  ER_PS_MANY_PARAM,
+  ER_KEY_PART_0,
+  ER_VIEW_CHECKSUM,
+  ER_VIEW_MULTIUPDATE,
+  ER_VIEW_NO_INSERT_FIELD_LIST,
+  ER_VIEW_DELETE_MERGE_VIEW,
+  ER_CANNOT_USER,
+  ER_XAER_NOTA,
+  ER_XAER_INVAL,
+  ER_XAER_RMFAIL,
+  ER_XAER_OUTSIDE,
+  ER_XAER_RMERR,
+  ER_XA_RBROLLBACK,
+  ER_NONEXISTING_PROC_GRANT,
+  ER_PROC_AUTO_GRANT_FAIL,
+  ER_PROC_AUTO_REVOKE_FAIL,
+  ER_DATA_TOO_LONG,
+  ER_SP_BAD_SQLSTATE,
+  ER_STARTUP,
+  ER_LOAD_FROM_FIXED_SIZE_ROWS_TO_VAR,
+  ER_CANT_CREATE_USER_WITH_GRANT,
+  ER_WRONG_VALUE_FOR_TYPE,
+  ER_TABLE_DEF_CHANGED,
+  ER_SP_DUP_HANDLER,
+  ER_SP_NOT_VAR_ARG,
+  ER_SP_NO_RETSET,
+  ER_CANT_CREATE_GEOMETRY_OBJECT,
+  ER_FAILED_ROUTINE_BREAK_BINLOG,
+  ER_BINLOG_UNSAFE_ROUTINE,
+  ER_BINLOG_CREATE_ROUTINE_NEED_SUPER,
+  ER_EXEC_STMT_WITH_OPEN_CURSOR,
+  ER_STMT_HAS_NO_OPEN_CURSOR,
+  ER_COMMIT_NOT_ALLOWED_IN_SF_OR_TRG,
+  ER_NO_DEFAULT_FOR_VIEW_FIELD,
+  ER_SP_NO_RECURSION,
+  ER_TOO_BIG_SCALE,
+  ER_TOO_BIG_PRECISION,
+  ER_M_BIGGER_THAN_D,
+  ER_WRONG_LOCK_OF_SYSTEM_TABLE,
+  ER_CONNECT_TO_FOREIGN_DATA_SOURCE,
+  ER_QUERY_ON_FOREIGN_DATA_SOURCE,
+  ER_FOREIGN_DATA_SOURCE_DOESNT_EXIST,
+  ER_FOREIGN_DATA_STRING_INVALID_CANT_CREATE,
+  ER_FOREIGN_DATA_STRING_INVALID,
+  ER_CANT_CREATE_FEDERATED_TABLE,
+  ER_TRG_IN_WRONG_SCHEMA,
+  ER_STACK_OVERRUN_NEED_MORE,
+  ER_TOO_LONG_BODY,
+  ER_WARN_CANT_DROP_DEFAULT_KEYCACHE,
+  ER_TOO_BIG_DISPLAYWIDTH,
+  ER_XAER_DUPID,
+  ER_DATETIME_FUNCTION_OVERFLOW,
+  ER_CANT_UPDATE_USED_TABLE_IN_SF_OR_TRG,
+  ER_VIEW_PREVENT_UPDATE,
+  ER_PS_NO_RECURSION,
+  ER_SP_CANT_SET_AUTOCOMMIT,
+  ER_MALFORMED_DEFINER,
+  ER_VIEW_FRM_NO_USER,
+  ER_VIEW_OTHER_USER,
+  ER_NO_SUCH_USER,
+  ER_FORBID_SCHEMA_CHANGE,
+  ER_ROW_IS_REFERENCED_2,
+  ER_NO_REFERENCED_ROW_2,
+  ER_SP_BAD_VAR_SHADOW,
+  ER_TRG_NO_DEFINER,
+  ER_OLD_FILE_FORMAT,
+  ER_SP_RECURSION_LIMIT,
+  ER_SP_PROC_TABLE_CORRUPT,
+  ER_SP_WRONG_NAME,
+  ER_TABLE_NEEDS_UPGRADE,
+  ER_SP_NO_AGGREGATE,
+  ER_MAX_PREPARED_STMT_COUNT_REACHED,
+  ER_VIEW_RECURSIVE,
+  ER_NON_GROUPING_FIELD_USED,
+  ER_TABLE_CANT_HANDLE_SPKEYS,
+  ER_NO_TRIGGERS_ON_SYSTEM_SCHEMA,
+  ER_REMOVED_SPACES,
+  ER_AUTOINC_READ_FAILED,
+  ER_USERNAME,
+  ER_HOSTNAME,
+  ER_WRONG_STRING_LENGTH,
+  ER_NON_INSERTABLE_TABLE,
+  ER_ADMIN_WRONG_MRG_TABLE,
+  ER_TOO_HIGH_LEVEL_OF_NESTING_FOR_SELECT,
+  ER_NAME_BECOMES_EMPTY,
+  ER_AMBIGUOUS_FIELD_TERM,
+  ER_FOREIGN_SERVER_EXISTS,
+  ER_FOREIGN_SERVER_DOESNT_EXIST,
+  ER_ILLEGAL_HA_CREATE_OPTION,
+  ER_PARTITION_REQUIRES_VALUES_ERROR,
+  ER_PARTITION_WRONG_VALUES_ERROR,
+  ER_PARTITION_MAXVALUE_ERROR,
+  ER_PARTITION_SUBPARTITION_ERROR,
+  ER_PARTITION_SUBPART_MIX_ERROR,
+  ER_PARTITION_WRONG_NO_PART_ERROR,
+  ER_PARTITION_WRONG_NO_SUBPART_ERROR,
+  ER_CONST_EXPR_IN_PARTITION_FUNC_ERROR,
+  ER_NO_CONST_EXPR_IN_RANGE_OR_LIST_ERROR,
+  ER_FIELD_NOT_FOUND_PART_ERROR,
+  ER_LIST_OF_FIELDS_ONLY_IN_HASH_ERROR,
+  ER_INCONSISTENT_PARTITION_INFO_ERROR,
+  ER_PARTITION_FUNC_NOT_ALLOWED_ERROR,
+  ER_PARTITIONS_MUST_BE_DEFINED_ERROR,
+  ER_RANGE_NOT_INCREASING_ERROR,
+  ER_INCONSISTENT_TYPE_OF_FUNCTIONS_ERROR,
+  ER_MULTIPLE_DEF_CONST_IN_LIST_PART_ERROR,
+  ER_PARTITION_ENTRY_ERROR,
+  ER_MIX_HANDLER_ERROR,
+  ER_PARTITION_NOT_DEFINED_ERROR,
+  ER_TOO_MANY_PARTITIONS_ERROR,
+  ER_SUBPARTITION_ERROR,
+  ER_CANT_CREATE_HANDLER_FILE,
+  ER_BLOB_FIELD_IN_PART_FUNC_ERROR,
+  ER_UNIQUE_KEY_NEED_ALL_FIELDS_IN_PF,
+  ER_NO_PARTS_ERROR,
+  ER_PARTITION_MGMT_ON_NONPARTITIONED,
+  ER_FOREIGN_KEY_ON_PARTITIONED,
+  ER_DROP_PARTITION_NON_EXISTENT,
+  ER_DROP_LAST_PARTITION,
+  ER_COALESCE_ONLY_ON_HASH_PARTITION,
+  ER_REORG_HASH_ONLY_ON_SAME_NO,
+  ER_REORG_NO_PARAM_ERROR,
+  ER_ONLY_ON_RANGE_LIST_PARTITION,
+  ER_ADD_PARTITION_SUBPART_ERROR,
+  ER_ADD_PARTITION_NO_NEW_PARTITION,
+  ER_COALESCE_PARTITION_NO_PARTITION,
+  ER_REORG_PARTITION_NOT_EXIST,
+  ER_SAME_NAME_PARTITION,
+  ER_NO_BINLOG_ERROR,
+  ER_CONSECUTIVE_REORG_PARTITIONS,
+  ER_REORG_OUTSIDE_RANGE,
+  ER_PARTITION_FUNCTION_FAILURE,
+  ER_PART_STATE_ERROR,
+  ER_LIMITED_PART_RANGE,
+  ER_PLUGIN_IS_NOT_LOADED,
+  ER_WRONG_VALUE,
+  ER_NO_PARTITION_FOR_GIVEN_VALUE,
+  ER_FILEGROUP_OPTION_ONLY_ONCE,
+  ER_CREATE_FILEGROUP_FAILED,
+  ER_DROP_FILEGROUP_FAILED,
+  ER_TABLESPACE_AUTO_EXTEND_ERROR,
+  ER_WRONG_SIZE_NUMBER,
+  ER_SIZE_OVERFLOW_ERROR,
+  ER_ALTER_FILEGROUP_FAILED,
+  ER_BINLOG_ROW_LOGGING_FAILED,
+  ER_BINLOG_ROW_WRONG_TABLE_DEF,
+  ER_BINLOG_ROW_RBR_TO_SBR,
+  ER_EVENT_ALREADY_EXISTS,
+  ER_EVENT_STORE_FAILED,
+  ER_EVENT_DOES_NOT_EXIST,
+  ER_EVENT_CANT_ALTER,
+  ER_EVENT_DROP_FAILED,
+  ER_EVENT_INTERVAL_NOT_POSITIVE_OR_TOO_BIG,
+  ER_EVENT_ENDS_BEFORE_STARTS,
+  ER_EVENT_EXEC_TIME_IN_THE_PAST,
+  ER_EVENT_OPEN_TABLE_FAILED,
+  ER_EVENT_NEITHER_M_EXPR_NOR_M_AT,
+  ER_COL_COUNT_DOESNT_MATCH_CORRUPTED,
+  ER_CANNOT_LOAD_FROM_TABLE,
+  ER_EVENT_CANNOT_DELETE,
+  ER_EVENT_COMPILE_ERROR,
+  ER_EVENT_SAME_NAME,
+  ER_EVENT_DATA_TOO_LONG,
+  ER_DROP_INDEX_FK,
+  ER_WARN_DEPRECATED_SYNTAX_WITH_VER,
+  ER_CANT_WRITE_LOCK_LOG_TABLE,
+  ER_CANT_LOCK_LOG_TABLE,
+  ER_FOREIGN_DUPLICATE_KEY,
+  ER_COL_COUNT_DOESNT_MATCH_PLEASE_UPDATE,
+  ER_TEMP_TABLE_PREVENTS_SWITCH_OUT_OF_RBR,
+  ER_STORED_FUNCTION_PREVENTS_SWITCH_BINLOG_FORMAT,
+  ER_NDB_CANT_SWITCH_BINLOG_FORMAT,
+  ER_PARTITION_NO_TEMPORARY,
+  ER_PARTITION_CONST_DOMAIN_ERROR,
+  ER_PARTITION_FUNCTION_IS_NOT_ALLOWED,
+  ER_DDL_LOG_ERROR,
+  ER_NULL_IN_VALUES_LESS_THAN,
+  ER_WRONG_PARTITION_NAME,
+  ER_CANT_CHANGE_TX_ISOLATION,
+  ER_DUP_ENTRY_AUTOINCREMENT_CASE,
+  ER_EVENT_MODIFY_QUEUE_ERROR,
+  ER_EVENT_SET_VAR_ERROR,
+  ER_PARTITION_MERGE_ERROR,
+  ER_CANT_ACTIVATE_LOG,
+  ER_RBR_NOT_AVAILABLE,
+  ER_BASE64_DECODE_ERROR,
+  ER_EVENT_RECURSION_FORBIDDEN,
+  ER_EVENTS_DB_ERROR,
+  ER_ONLY_INTEGERS_ALLOWED,
+  ER_UNSUPORTED_LOG_ENGINE,
+  ER_BAD_LOG_STATEMENT,
+  ER_CANT_RENAME_LOG_TABLE,
+  ER_WRONG_PARAMCOUNT_TO_NATIVE_FCT,
+  ER_WRONG_PARAMETERS_TO_NATIVE_FCT,
+  ER_WRONG_PARAMETERS_TO_STORED_FCT,
+  ER_NATIVE_FCT_NAME_COLLISION,
+  ER_DUP_ENTRY_WITH_KEY_NAME,
+  ER_BINLOG_PURGE_EMFILE,
+  ER_EVENT_CANNOT_CREATE_IN_THE_PAST,
+  ER_EVENT_CANNOT_ALTER_IN_THE_PAST,
+  ER_SLAVE_INCIDENT,
+  ER_NO_PARTITION_FOR_GIVEN_VALUE_SILENT,
+  ER_BINLOG_UNSAFE_STATEMENT,
+  ER_SLAVE_FATAL_ERROR,
+  ER_SLAVE_RELAY_LOG_READ_FAILURE,
+  ER_SLAVE_RELAY_LOG_WRITE_FAILURE,
+  ER_SLAVE_CREATE_EVENT_FAILURE,
+  ER_SLAVE_MASTER_COM_FAILURE,
+  ER_BINLOG_LOGGING_IMPOSSIBLE,
+  ER_VIEW_NO_CREATION_CTX,
+  ER_VIEW_INVALID_CREATION_CTX,
+  ER_SR_INVALID_CREATION_CTX,
+  ER_TRG_CORRUPTED_FILE,
+  ER_TRG_NO_CREATION_CTX,
+  ER_TRG_INVALID_CREATION_CTX,
+  ER_EVENT_INVALID_CREATION_CTX,
+  ER_TRG_CANT_OPEN_TABLE,
+  ER_CANT_CREATE_SROUTINE,
+  ER_SLAVE_AMBIGOUS_EXEC_MODE,
+  ER_NO_FORMAT_DESCRIPTION_EVENT_BEFORE_BINLOG_STATEMENT,
+  ER_SLAVE_CORRUPT_EVENT,
+  ER_LOAD_DATA_INVALID_COLUMN,
+  ER_LOG_PURGE_NO_FILE,
+  ER_WARN_AUTO_CONVERT_LOCK,
+  ER_NO_AUTO_CONVERT_LOCK_STRICT,
+  ER_NO_AUTO_CONVERT_LOCK_TRANSACTION,
+  ER_NO_STORAGE_ENGINE,
+  ER_BACKUP_BACKUP_START,
+  ER_BACKUP_BACKUP_DONE,
+  ER_BACKUP_RESTORE_START,
+  ER_BACKUP_RESTORE_DONE,
+  ER_BACKUP_NOTHING_TO_BACKUP,
+  ER_BACKUP_CANNOT_INCLUDE_DB,
+  ER_BACKUP_BACKUP,
+  ER_BACKUP_RESTORE,
+  ER_BACKUP_RUNNING,
+  ER_BACKUP_BACKUP_PREPARE,
+  ER_BACKUP_RESTORE_PREPARE,
+  ER_BACKUP_INVALID_LOC,
+  ER_BACKUP_READ_LOC,
+  ER_BACKUP_WRITE_LOC,
+  ER_BACKUP_LIST_DBS,
+  ER_BACKUP_LIST_TABLES,
+  ER_BACKUP_LIST_DB_TABLES,
+  ER_BACKUP_SKIP_VIEW,
+  ER_BACKUP_NO_ENGINE,
+  ER_BACKUP_TABLE_OPEN,
+  ER_BACKUP_READ_HEADER,
+  ER_BACKUP_WRITE_HEADER,
+  ER_BACKUP_NO_BACKUP_DRIVER,
+  ER_BACKUP_NOT_ACCEPTED,
+  ER_BACKUP_CREATE_BACKUP_DRIVER,
+  ER_BACKUP_CREATE_RESTORE_DRIVER,
+  ER_BACKUP_TOO_MANY_IMAGES,
+  ER_BACKUP_WRITE_META,
+  ER_BACKUP_READ_META,
+  ER_BACKUP_CREATE_META,
+  ER_BACKUP_GET_BUF,
+  ER_BACKUP_WRITE_DATA,
+  ER_BACKUP_READ_DATA,
+  ER_BACKUP_NEXT_CHUNK,
+  ER_BACKUP_INIT_BACKUP_DRIVER,
+  ER_BACKUP_INIT_RESTORE_DRIVER,
+  ER_BACKUP_STOP_BACKUP_DRIVER,
+  ER_BACKUP_STOP_RESTORE_DRIVERS,
+  ER_BACKUP_PREPARE_DRIVER,
+  ER_BACKUP_CREATE_VP,
+  ER_BACKUP_UNLOCK_DRIVER,
+  ER_BACKUP_CANCEL_BACKUP,
+  ER_BACKUP_CANCEL_RESTORE,
+  ER_BACKUP_GET_DATA,
+  ER_BACKUP_SEND_DATA,
+  ER_BACKUP_SEND_DATA_RETRY,
+  ER_BACKUP_OPEN_TABLES,
+  ER_BACKUP_THREAD_INIT,
+  ER_BACKUP_PROGRESS_TABLES,
+  ER_TABLESPACE_EXIST,
+  ER_NO_SUCH_TABLESPACE,
+  ER_SLAVE_HEARTBEAT_FAILURE,
+  ER_SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE,
+  ER_BACKUP_LOG_WRITE_ERROR,
+  ER_TABLESPACE_NOT_EMPTY,
+  ER_BACKUP_TS_CHANGE,
+  ER_ERROR_LAST= ER_BACKUP_TS_CHANGE
+};
+
+#endif
+

=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2008-07-28 18:01:38 +0000
+++ drizzled/field.cc	2008-07-30 18:03:54 +0000
@@ -758,7 +758,7 @@
   /* Test if we have garbage at the end of the given string. */
   if (test_if_important_data(cs, int_end, str + length))
   {
-    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
     return 2;
   }
   return 0;
@@ -851,7 +851,7 @@
   }
   if (op_result == E_DEC_TRUNCATED)
   {
-    set_warning(MYSQL_ERROR::WARN_LEVEL_NOTE, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_NOTE, ER_WARN_DATA_TRUNCATED, 1);
     /* We return 0 here as this is not a critical issue */
   }
   return 0;
@@ -1733,10 +1733,10 @@
       if (table->in_use->abort_on_warning)
         set_warning(MYSQL_ERROR::WARN_LEVEL_ERROR, ER_DATA_TOO_LONG, 1);
       else
-        set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+        set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
     }
     else /* If we lost only spaces then produce a NOTE, not a WARNING */
-      set_warning(MYSQL_ERROR::WARN_LEVEL_NOTE, WARN_DATA_TRUNCATED, 1);
+      set_warning(MYSQL_ERROR::WARN_LEVEL_NOTE, ER_WARN_DATA_TRUNCATED, 1);
     return 2;
   }
   return 0;
@@ -1764,7 +1764,7 @@
     if (table->in_use->abort_on_warning)
       set_warning(MYSQL_ERROR::WARN_LEVEL_ERROR, ER_DATA_TOO_LONG, 1);
     else
-      set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+      set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
   }
   return store(buff, length, charset());
 }
@@ -1902,13 +1902,13 @@
       if (err || end != from+length || tmp > typelib->count)
       {
 	tmp=0;
-	set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+	set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
       }
       if (!table->in_use->count_cuted_fields)
         err= 0;
     }
     else
-      set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+      set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
   }
   store_type((uint64_t) tmp);
   return err;
@@ -1927,7 +1927,7 @@
   int error= 0;
   if ((uint64_t) nr > typelib->count || nr == 0)
   {
-    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
     if (nr != 0 || table->in_use->count_cuted_fields)
     {
       nr= 0;
@@ -2820,7 +2820,8 @@
 */
 
 void 
-Field::set_datetime_warning(MYSQL_ERROR::enum_warning_level level, uint code, 
+Field::set_datetime_warning(MYSQL_ERROR::enum_warning_level level, 
+                            unsigned int code, 
                             const char *str, uint str_length, 
                             timestamp_type ts_type, int cuted_increment)
 {

=== modified file 'drizzled/field/date.cc'
--- drizzled/field/date.cc	2008-07-27 21:07:26 +0000
+++ drizzled/field/date.cc	2008-07-30 18:03:54 +0000
@@ -79,7 +79,7 @@
   if (error)
     set_datetime_warning(error == 3 ? MYSQL_ERROR::WARN_LEVEL_NOTE :
                          MYSQL_ERROR::WARN_LEVEL_WARN,
-                         WARN_DATA_TRUNCATED,
+                         ER_WARN_DATA_TRUNCATED,
                          from, len, MYSQL_TIMESTAMP_DATE, 1);
 
   int3store(ptr, tmp);
@@ -93,7 +93,7 @@
   {
     int3store(ptr,(int32_t) 0);
     set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                         WARN_DATA_TRUNCATED, nr, MYSQL_TIMESTAMP_DATE);
+                         ER_WARN_DATA_TRUNCATED, nr, MYSQL_TIMESTAMP_DATE);
     return 1;
   }
   return Field_newdate::store((int64_t) rint(nr), false);
@@ -128,7 +128,7 @@
     set_datetime_warning(error == 3 ? MYSQL_ERROR::WARN_LEVEL_NOTE :
                          MYSQL_ERROR::WARN_LEVEL_WARN,
                          error == 2 ? 
-                         ER_WARN_DATA_OUT_OF_RANGE : WARN_DATA_TRUNCATED,
+                         ER_WARN_DATA_OUT_OF_RANGE : ER_WARN_DATA_TRUNCATED,
                          nr,MYSQL_TIMESTAMP_DATE, 1);
 
   int3store(ptr,tmp);
@@ -153,7 +153,7 @@
       char buff[MAX_DATE_STRING_REP_LENGTH];
       String str(buff, sizeof(buff), &my_charset_latin1);
       make_date((DATE_TIME_FORMAT *) 0, ltime, &str);
-      set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED,
+      set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED,
                            str.ptr(), str.length(), MYSQL_TIMESTAMP_DATE, 1);
     }
     if (!error && ltime->time_type != MYSQL_TIMESTAMP_DATE &&
@@ -163,7 +163,7 @@
       String str(buff, sizeof(buff), &my_charset_latin1);
       make_datetime((DATE_TIME_FORMAT *) 0, ltime, &str);
       set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_NOTE,
-                           WARN_DATA_TRUNCATED,
+                           ER_WARN_DATA_TRUNCATED,
                            str.ptr(), str.length(), MYSQL_TIMESTAMP_DATE, 1);
       error= 3;
     }
@@ -172,7 +172,7 @@
   {
     tmp=0;
     error= 1;
-    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
   }
   int3store(ptr,tmp);
   return error;

=== modified file 'drizzled/field/datetime.cc'
--- drizzled/field/datetime.cc	2008-07-27 21:07:26 +0000
+++ drizzled/field/datetime.cc	2008-07-30 18:03:54 +0000
@@ -108,7 +108,7 @@
   if (error)
     set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
                          error == 2 ? ER_WARN_DATA_OUT_OF_RANGE :
-                         WARN_DATA_TRUNCATED, initial_nr,
+                         ER_WARN_DATA_TRUNCATED, initial_nr,
                          MYSQL_TIMESTAMP_DATETIME, 1);
 
 #ifdef WORDS_BIGENDIAN
@@ -145,7 +145,7 @@
       char buff[MAX_DATE_STRING_REP_LENGTH];
       String str(buff, sizeof(buff), &my_charset_latin1);
       make_datetime((DATE_TIME_FORMAT *) 0, ltime, &str);
-      set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED,
+      set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED,
                            str.ptr(), str.length(), MYSQL_TIMESTAMP_DATETIME,1);
     }
   }
@@ -153,7 +153,7 @@
   {
     tmp=0;
     error= 1;
-    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
   }
 #ifdef WORDS_BIGENDIAN
   if (table && table->s->db_low_byte_first)

=== modified file 'drizzled/field/double.cc'
--- drizzled/field/double.cc	2008-07-28 00:57:12 +0000
+++ drizzled/field/double.cc	2008-07-30 18:03:54 +0000
@@ -36,7 +36,7 @@
   if (error || (!len || (((uint) (end-from) != len) && table->in_use->count_cuted_fields)))
   {
     set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                (error ? ER_WARN_DATA_OUT_OF_RANGE : WARN_DATA_TRUNCATED), 1);
+                (error ? ER_WARN_DATA_OUT_OF_RANGE : ER_WARN_DATA_TRUNCATED), 1);
     error= error ? 1 : 2;
   }
   Field_double::store(nr);

=== modified file 'drizzled/field/fdecimal.cc'
--- drizzled/field/fdecimal.cc	2008-07-28 00:57:12 +0000
+++ drizzled/field/fdecimal.cc	2008-07-30 18:03:54 +0000
@@ -158,7 +158,7 @@
 
   switch (err) {
   case E_DEC_TRUNCATED:
-    set_warning(MYSQL_ERROR::WARN_LEVEL_NOTE, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_NOTE, ER_WARN_DATA_TRUNCATED, 1);
     break;
   case E_DEC_OVERFLOW:
     set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_OUT_OF_RANGE, 1);

=== modified file 'drizzled/field/set.cc'
--- drizzled/field/set.cc	2008-07-27 21:07:26 +0000
+++ drizzled/field/set.cc	2008-07-30 18:03:54 +0000
@@ -64,11 +64,11 @@
 	tmp > (uint64_t) (((int64_t) 1 << typelib->count) - (int64_t) 1))
     {
       tmp=0;      
-      set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+      set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
     }
   }
   else if (got_warning)
-    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
   store_type(tmp);
   return err;
 }
@@ -82,7 +82,7 @@
   if ((uint64_t) nr > max_nr)
   {
     nr&= max_nr;
-    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+    set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
     error=1;
   }
   store_type((uint64_t) nr);

=== modified file 'drizzled/field/timestamp.cc'
--- drizzled/field/timestamp.cc	2008-07-29 07:47:38 +0000
+++ drizzled/field/timestamp.cc	2008-07-30 18:03:54 +0000
@@ -158,7 +158,7 @@
   if (error || !have_smth_to_conv)
   {
     error= 1;
-    set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED,
+    set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED,
                          from, len, MYSQL_TIMESTAMP_DATETIME, 1);
   }
 
@@ -237,7 +237,7 @@
     }
   } else if (error)
     set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                         WARN_DATA_TRUNCATED,
+                         ER_WARN_DATA_TRUNCATED,
                          nr, MYSQL_TIMESTAMP_DATETIME, 1);
 
   store_timestamp(timestamp);

=== modified file 'drizzled/field/timetype.cc'
--- drizzled/field/timetype.cc	2008-07-27 21:07:26 +0000
+++ drizzled/field/timetype.cc	2008-07-30 18:03:54 +0000
@@ -44,7 +44,7 @@
   {
     tmp=0L;
     error= 2;
-    set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED,
+    set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED,
                          from, len, MYSQL_TIMESTAMP_TIME, 1);
   }
   else
@@ -52,7 +52,7 @@
     if (warning & MYSQL_TIME_WARN_TRUNCATED)
     {
       set_datetime_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                           WARN_DATA_TRUNCATED,
+                           ER_WARN_DATA_TRUNCATED,
                            from, len, MYSQL_TIMESTAMP_TIME, 1);
       error= 1;
     }

=== modified file 'drizzled/field_conv.cc'
--- drizzled/field_conv.cc	2008-07-29 07:47:38 +0000
+++ drizzled/field_conv.cc	2008-07-30 18:03:54 +0000
@@ -124,7 +124,7 @@
   field->reset();
   if (field->table->in_use->count_cuted_fields == CHECK_FIELD_WARN)
   {
-    field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, WARN_DATA_TRUNCATED, 1);
+    field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
     return 0;
   }
   if (!field->table->in_use->no_errors)
@@ -230,7 +230,7 @@
   if (*copy->from_null_ptr & copy->from_bit)
   {
     copy->to_field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                                WARN_DATA_TRUNCATED, 1);
+                                ER_WARN_DATA_TRUNCATED, 1);
     copy->to_field->reset();
   }
   else
@@ -372,7 +372,7 @@
                      MY_SEQ_SPACES) < copy->from_length - copy->to_length)
   {
     copy->to_field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                                WARN_DATA_TRUNCATED, 1);
+                                ER_WARN_DATA_TRUNCATED, 1);
   }
 }
 
@@ -403,7 +403,7 @@
                      MY_SEQ_SPACES) < (copy->from_length - copy_length))
   {
     copy->to_field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                                WARN_DATA_TRUNCATED, 1);
+                                ER_WARN_DATA_TRUNCATED, 1);
   }
 
   if (copy_length < copy->to_length)
@@ -441,7 +441,7 @@
     length=copy->to_length - 1;
     if (copy->from_field->table->in_use->count_cuted_fields)
       copy->to_field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                                  WARN_DATA_TRUNCATED, 1);
+                                  ER_WARN_DATA_TRUNCATED, 1);
   }
   *(uchar*) copy->to_ptr= (uchar) length;
   memcpy(copy->to_ptr+1, copy->from_ptr + 1, length);
@@ -462,7 +462,7 @@
   {
     if (current_thd->count_cuted_fields)
       copy->to_field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                                  WARN_DATA_TRUNCATED, 1);
+                                  ER_WARN_DATA_TRUNCATED, 1);
   }
   *copy->to_ptr= (uchar) length;
   memcpy(copy->to_ptr + 1, from_ptr, length);
@@ -477,7 +477,7 @@
     length=copy->to_length-HA_KEY_BLOB_LENGTH;
     if (copy->from_field->table->in_use->count_cuted_fields)
       copy->to_field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                                  WARN_DATA_TRUNCATED, 1);
+                                  ER_WARN_DATA_TRUNCATED, 1);
   }
   int2store(copy->to_ptr,length);
   memcpy(copy->to_ptr+HA_KEY_BLOB_LENGTH, copy->from_ptr + HA_KEY_BLOB_LENGTH,
@@ -499,7 +499,7 @@
   {
     if (current_thd->count_cuted_fields)
       copy->to_field->set_warning(MYSQL_ERROR::WARN_LEVEL_WARN,
-                                  WARN_DATA_TRUNCATED, 1);
+                                  ER_WARN_DATA_TRUNCATED, 1);
   }  
   int2store(copy->to_ptr, length);
   memcpy(copy->to_ptr+HA_KEY_BLOB_LENGTH, from_beg, length);

=== modified file 'drizzled/my_decimal.cc'
--- drizzled/my_decimal.cc	2008-07-13 22:45:08 +0000
+++ drizzled/my_decimal.cc	2008-07-30 18:03:54 +0000
@@ -37,7 +37,7 @@
     break;
   case E_DEC_TRUNCATED:
     push_warning_printf(current_thd, MYSQL_ERROR::WARN_LEVEL_WARN,
-			WARN_DATA_TRUNCATED, ER(WARN_DATA_TRUNCATED),
+			ER_WARN_DATA_TRUNCATED, ER(ER_WARN_DATA_TRUNCATED),
 			"", (long)-1);
     break;
   case E_DEC_OVERFLOW:

=== modified file 'drizzled/mysql_priv.h'
--- drizzled/mysql_priv.h	2008-07-30 05:33:20 +0000
+++ drizzled/mysql_priv.h	2008-07-30 18:03:54 +0000
@@ -36,6 +36,7 @@
 #include <mysys/hash.h>
 #include <signal.h>
 #include <mysys/thr_lock.h>
+#include <drizzled/error.h>
 #include <drizzled/base.h>			/* Needed by field.h */
 #include <mysys/queues.h>
 #include "sql_bitmap.h"

=== modified file 'drizzled/sql_state.c'
--- drizzled/sql_state.c	2008-07-30 05:33:20 +0000
+++ drizzled/sql_state.c	2008-07-30 18:03:54 +0000
@@ -16,20 +16,9 @@
 /* Functions to map mysqld errno to sql_state */
 
 #include "global.h"
-#include <drizzled_error.h>
+#include <drizzled/error.h>
 #include <libdrizzle/drizzle.h>
-
-struct st_map_errno_to_sqlstate
-{
-  uint mysql_errno;
-  const char *odbc_state;
-  const char *jdbc_state;
-};
-
-struct st_map_errno_to_sqlstate sqlstate_map[]=
-{
-#include <sql_state.h>
-};
+#include "sql_state.h"
 
 const char *mysql_errno_to_sqlstate(uint mysql_errno)
 {

=== added file 'drizzled/sql_state.h'
--- drizzled/sql_state.h	1970-01-01 00:00:00 +0000
+++ drizzled/sql_state.h	2008-07-30 18:03:54 +0000
@@ -0,0 +1,241 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 MySQL
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef _drizzled_sql_state_h
+#define _drizzled_sql_state_h
+
+struct st_map_errno_to_sqlstate
+{
+  uint mysql_errno;
+  const char *odbc_state;
+  const char *jdbc_state;
+};
+
+struct st_map_errno_to_sqlstate sqlstate_map[]=
+{
+  { ER_DUP_KEY                              ,"23000", "" },
+  { ER_OUTOFMEMORY                          ,"HY001", "S1001" },
+  { ER_OUT_OF_SORTMEMORY                    ,"HY001", "S1001" },
+  { ER_CON_COUNT_ERROR                      ,"08004", "" },
+  { ER_BAD_HOST_ERROR                       ,"08S01", "" },
+  { ER_HANDSHAKE_ERROR                      ,"08S01", "" },
+  { ER_DBACCESS_DENIED_ERROR                ,"42000", "" },
+  { ER_ACCESS_DENIED_ERROR                  ,"28000", "" },
+  { ER_NO_DB_ERROR                          ,"3D000", "" },
+  { ER_UNKNOWN_COM_ERROR                    ,"08S01", "" },
+  { ER_BAD_NULL_ERROR                       ,"23000", "" },
+  { ER_BAD_DB_ERROR                         ,"42000", "" },
+  { ER_TABLE_EXISTS_ERROR                   ,"42S01", "" },
+  { ER_BAD_TABLE_ERROR                      ,"42S02", "" },
+  { ER_NON_UNIQ_ERROR                       ,"23000", "" },
+  { ER_SERVER_SHUTDOWN                      ,"08S01", "" },
+  { ER_BAD_FIELD_ERROR                      ,"42S22", "S0022" },
+  { ER_WRONG_FIELD_WITH_GROUP               ,"42000", "S1009" },
+  { ER_WRONG_GROUP_FIELD                    ,"42000", "S1009" },
+  { ER_WRONG_SUM_SELECT                     ,"42000", "S1009" },
+  { ER_WRONG_VALUE_COUNT                    ,"21S01", "" },
+  { ER_TOO_LONG_IDENT                       ,"42000", "S1009" },
+  { ER_DUP_FIELDNAME                        ,"42S21", "S1009" },
+  { ER_DUP_KEYNAME                          ,"42000", "S1009" },
+  { ER_DUP_ENTRY                            ,"23000", "S1009" },
+  { ER_WRONG_FIELD_SPEC                     ,"42000", "S1009" },
+  { ER_PARSE_ERROR                          ,"42000", "s1009" },
+  { ER_EMPTY_QUERY                          ,"42000", "" },
+  { ER_NONUNIQ_TABLE                        ,"42000", "S1009" },
+  { ER_INVALID_DEFAULT                      ,"42000", "S1009" },
+  { ER_MULTIPLE_PRI_KEY                     ,"42000", "S1009" },
+  { ER_TOO_MANY_KEYS                        ,"42000", "S1009" },
+  { ER_TOO_MANY_KEY_PARTS                   ,"42000", "S1009" },
+  { ER_TOO_LONG_KEY                         ,"42000", "S1009" },
+  { ER_KEY_COLUMN_DOES_NOT_EXITS            ,"42000", "S1009" },
+  { ER_BLOB_USED_AS_KEY                     ,"42000", "S1009" },
+  { ER_TOO_BIG_FIELDLENGTH                  ,"42000", "S1009" },
+  { ER_WRONG_AUTO_KEY                       ,"42000", "S1009" },
+  { ER_FORCING_CLOSE                        ,"08S01", "" },
+  { ER_IPSOCK_ERROR                         ,"08S01", "" },
+  { ER_NO_SUCH_INDEX                        ,"42S12", "S1009" },
+  { ER_WRONG_FIELD_TERMINATORS              ,"42000", "S1009" },
+  { ER_BLOBS_AND_NO_TERMINATED              ,"42000", "S1009" },
+  { ER_CANT_REMOVE_ALL_FIELDS               ,"42000", "" },
+  { ER_CANT_DROP_FIELD_OR_KEY               ,"42000", "" },
+  { ER_BLOB_CANT_HAVE_DEFAULT               ,"42000", "" },
+  { ER_WRONG_DB_NAME                        ,"42000", "" },
+  { ER_WRONG_TABLE_NAME                     ,"42000", "" },
+  { ER_TOO_BIG_SELECT                       ,"42000", "" },
+  { ER_UNKNOWN_PROCEDURE                    ,"42000", "" },
+  { ER_WRONG_PARAMCOUNT_TO_PROCEDURE        ,"42000", "" },
+  { ER_UNKNOWN_TABLE                        ,"42S02", "" },
+  { ER_FIELD_SPECIFIED_TWICE                ,"42000", "" },
+  { ER_UNSUPPORTED_EXTENSION                ,"42000", "" },
+  { ER_TABLE_MUST_HAVE_COLUMNS              ,"42000", "" },
+  { ER_UNKNOWN_CHARACTER_SET                ,"42000", "" },
+  { ER_TOO_BIG_ROWSIZE                      ,"42000", "" },
+  { ER_WRONG_OUTER_JOIN                     ,"42000", "" },
+  { ER_NULL_COLUMN_IN_INDEX                 ,"42000", "" },
+  { ER_PASSWORD_ANONYMOUS_USER              ,"42000", "" },
+  { ER_PASSWORD_NOT_ALLOWED                 ,"42000", "" },
+  { ER_PASSWORD_NO_MATCH                    ,"42000", "" },
+  { ER_WRONG_VALUE_COUNT_ON_ROW             ,"21S01", "" },
+  { ER_INVALID_USE_OF_NULL                  ,"22004", "" },
+  { ER_REGEXP_ERROR                         ,"42000", "" },
+  { ER_MIX_OF_GROUP_FUNC_AND_FIELDS         ,"42000", "" },
+  { ER_NONEXISTING_GRANT                    ,"42000", "" },
+  { ER_TABLEACCESS_DENIED_ERROR             ,"42000", "" },
+  { ER_COLUMNACCESS_DENIED_ERROR            ,"42000", "" },
+  { ER_ILLEGAL_GRANT_FOR_TABLE              ,"42000", "" },
+  { ER_GRANT_WRONG_HOST_OR_USER             ,"42000", "" },
+  { ER_NO_SUCH_TABLE                        ,"42S02", "" },
+  { ER_NONEXISTING_TABLE_GRANT              ,"42000", "" },
+  { ER_NOT_ALLOWED_COMMAND                  ,"42000", "" },
+  { ER_SYNTAX_ERROR                         ,"42000", "" },
+  { ER_ABORTING_CONNECTION                  ,"08S01", "" },
+  { ER_NET_PACKET_TOO_LARGE                 ,"08S01", "" },
+  { ER_NET_READ_ERROR_FROM_PIPE             ,"08S01", "" },
+  { ER_NET_FCNTL_ERROR                      ,"08S01", "" },
+  { ER_NET_PACKETS_OUT_OF_ORDER             ,"08S01", "" },
+  { ER_NET_UNCOMPRESS_ERROR                 ,"08S01", "" },
+  { ER_NET_READ_ERROR                       ,"08S01", "" },
+  { ER_NET_READ_INTERRUPTED                 ,"08S01", "" },
+  { ER_NET_ERROR_ON_WRITE                   ,"08S01", "" },
+  { ER_NET_WRITE_INTERRUPTED                ,"08S01", "" },
+  { ER_TOO_LONG_STRING                      ,"42000", "" },
+  { ER_TABLE_CANT_HANDLE_BLOB               ,"42000", "" },
+  { ER_TABLE_CANT_HANDLE_AUTO_INCREMENT     ,"42000", "" },
+  { ER_WRONG_COLUMN_NAME                    ,"42000", "" },
+  { ER_WRONG_KEY_COLUMN                     ,"42000", "" },
+  { ER_DUP_UNIQUE                           ,"23000", "" },
+  { ER_BLOB_KEY_WITHOUT_LENGTH              ,"42000", "" },
+  { ER_PRIMARY_CANT_HAVE_NULL               ,"42000", "" },
+  { ER_TOO_MANY_ROWS                        ,"42000", "" },
+  { ER_REQUIRES_PRIMARY_KEY                 ,"42000", "" },
+  { ER_KEY_DOES_NOT_EXITS                   ,"42000", "S1009" },
+  { ER_CHECK_NO_SUCH_TABLE                  ,"42000", "" },
+  { ER_CHECK_NOT_IMPLEMENTED                ,"42000", "" },
+  { ER_CANT_DO_THIS_DURING_AN_TRANSACTION   ,"25000", "" },
+  { ER_NEW_ABORTING_CONNECTION              ,"08S01", "" },
+  { ER_MASTER_NET_READ                      ,"08S01", "" },
+  { ER_MASTER_NET_WRITE                     ,"08S01", "" },
+  { ER_TOO_MANY_USER_CONNECTIONS            ,"42000", "" },
+  { ER_READ_ONLY_TRANSACTION                ,"25000", "" },
+  { ER_NO_PERMISSION_TO_CREATE_USER         ,"42000", "" },
+  { ER_LOCK_DEADLOCK                        ,"40001", "" },
+  { ER_NO_REFERENCED_ROW                    ,"23000", "" },
+  { ER_ROW_IS_REFERENCED                    ,"23000", "" },
+  { ER_CONNECT_TO_MASTER                    ,"08S01", "" },
+  { ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT    ,"21000", "" },
+  { ER_USER_LIMIT_REACHED                   ,"42000", "" },
+  { ER_SPECIFIC_ACCESS_DENIED_ERROR         ,"42000", "" },
+  { ER_NO_DEFAULT                           ,"42000", "" },
+  { ER_WRONG_VALUE_FOR_VAR                  ,"42000", "" },
+  { ER_WRONG_TYPE_FOR_VAR                   ,"42000", "" },
+  { ER_CANT_USE_OPTION_HERE                 ,"42000", "" },
+  { ER_NOT_SUPPORTED_YET                    ,"42000", "" },
+  { ER_WRONG_FK_DEF                         ,"42000", "" },
+  { ER_OPERAND_COLUMNS                      ,"21000", "" },
+  { ER_SUBQUERY_NO_1_ROW                    ,"21000", "" },
+  { ER_ILLEGAL_REFERENCE                    ,"42S22", "" },
+  { ER_DERIVED_MUST_HAVE_ALIAS              ,"42000", "" },
+  { ER_SELECT_REDUCED                       ,"01000", "" },
+  { ER_TABLENAME_NOT_ALLOWED_HERE           ,"42000", "" },
+  { ER_NOT_SUPPORTED_AUTH_MODE              ,"08004", "" },
+  { ER_SPATIAL_CANT_HAVE_NULL               ,"42000", "" },
+  { ER_COLLATION_CHARSET_MISMATCH           ,"42000", "" },
+  { ER_WARN_TOO_FEW_RECORDS                 ,"01000", "" },
+  { ER_WARN_TOO_MANY_RECORDS                ,"01000", "" },
+  { ER_WARN_NULL_TO_NOTNULL                 ,"22004", "" },
+  { ER_WARN_DATA_OUT_OF_RANGE               ,"22003", "" },
+  { ER_WARN_DATA_TRUNCATED                  ,"01000", "" },
+  { ER_WRONG_NAME_FOR_INDEX                 ,"42000", "" },
+  { ER_WRONG_NAME_FOR_CATALOG               ,"42000", "" },
+  { ER_UNKNOWN_STORAGE_ENGINE               ,"42000", "" },
+  { ER_TRUNCATED_WRONG_VALUE                ,"22007", "" },
+  { ER_SP_NO_RECURSIVE_CREATE               ,"2F003", "" },
+  { ER_SP_ALREADY_EXISTS                    ,"42000", "" },
+  { ER_SP_DOES_NOT_EXIST                    ,"42000", "" },
+  { ER_SP_LILABEL_MISMATCH                  ,"42000", "" },
+  { ER_SP_LABEL_REDEFINE                    ,"42000", "" },
+  { ER_SP_LABEL_MISMATCH                    ,"42000", "" },
+  { ER_SP_UNINIT_VAR                        ,"01000", "" },
+  { ER_SP_BADSELECT                         ,"0A000", "" },
+  { ER_SP_BADRETURN                         ,"42000", "" },
+  { ER_SP_BADSTATEMENT                      ,"0A000", "" },
+  { ER_UPDATE_LOG_DEPRECATED_IGNORED        ,"42000", "" },
+  { ER_UPDATE_LOG_DEPRECATED_TRANSLATED     ,"42000", "" },
+  { ER_QUERY_INTERRUPTED                    ,"70100", "" },
+  { ER_SP_WRONG_NO_OF_ARGS                  ,"42000", "" },
+  { ER_SP_COND_MISMATCH                     ,"42000", "" },
+  { ER_SP_NORETURN                          ,"42000", "" },
+  { ER_SP_NORETURNEND                       ,"2F005", "" },
+  { ER_SP_BAD_CURSOR_QUERY                  ,"42000", "" },
+  { ER_SP_BAD_CURSOR_SELECT                 ,"42000", "" },
+  { ER_SP_CURSOR_MISMATCH                   ,"42000", "" },
+  { ER_SP_CURSOR_ALREADY_OPEN               ,"24000", "" },
+  { ER_SP_CURSOR_NOT_OPEN                   ,"24000", "" },
+  { ER_SP_UNDECLARED_VAR                    ,"42000", "" },
+  { ER_SP_FETCH_NO_DATA                     ,"02000", "" },
+  { ER_SP_DUP_PARAM                         ,"42000", "" },
+  { ER_SP_DUP_VAR                           ,"42000", "" },
+  { ER_SP_DUP_COND                          ,"42000", "" },
+  { ER_SP_DUP_CURS                          ,"42000", "" },
+  { ER_SP_SUBSELECT_NYI                     ,"0A000", "" },
+  { ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG        ,"0A000", "" },
+  { ER_SP_VARCOND_AFTER_CURSHNDLR           ,"42000", "" },
+  { ER_SP_CURSOR_AFTER_HANDLER              ,"42000", "" },
+  { ER_SP_CASE_NOT_FOUND                    ,"20000", "" },
+  { ER_DIVISION_BY_ZERO                     ,"22012", "" },
+  { ER_ILLEGAL_VALUE_FOR_TYPE               ,"22007", "" },
+  { ER_PROCACCESS_DENIED_ERROR              ,"42000", "" },
+  { ER_XAER_NOTA                            ,"XAE04", "" },
+  { ER_XAER_INVAL                           ,"XAE05", "" },
+  { ER_XAER_RMFAIL                          ,"XAE07", "" },
+  { ER_XAER_OUTSIDE                         ,"XAE09", "" },
+  { ER_XAER_RMERR                           ,"XAE03", "" },
+  { ER_XA_RBROLLBACK                        ,"XA100", "" },
+  { ER_NONEXISTING_PROC_GRANT               ,"42000", "" },
+  { ER_DATA_TOO_LONG                        ,"22001", "" },
+  { ER_SP_BAD_SQLSTATE                      ,"42000", "" },
+  { ER_CANT_CREATE_USER_WITH_GRANT          ,"42000", "" },
+  { ER_SP_DUP_HANDLER                       ,"42000", "" },
+  { ER_SP_NOT_VAR_ARG                       ,"42000", "" },
+  { ER_SP_NO_RETSET                         ,"0A000", "" },
+  { ER_CANT_CREATE_GEOMETRY_OBJECT          ,"22003", "" },
+  { ER_TOO_BIG_SCALE                        ,"42000", "S1009" },
+  { ER_TOO_BIG_PRECISION                    ,"42000", "S1009" },
+  { ER_M_BIGGER_THAN_D                      ,"42000", "S1009" },
+  { ER_TOO_LONG_BODY                        ,"42000", "S1009" },
+  { ER_TOO_BIG_DISPLAYWIDTH                 ,"42000", "S1009" },
+  { ER_XAER_DUPID                           ,"XAE08", "" },
+  { ER_DATETIME_FUNCTION_OVERFLOW           ,"22008", "" },
+  { ER_ROW_IS_REFERENCED_2                  ,"23000", "" },
+  { ER_NO_REFERENCED_ROW_2                  ,"23000", "" },
+  { ER_SP_BAD_VAR_SHADOW                    ,"42000", "" },
+  { ER_SP_WRONG_NAME                        ,"42000", "" },
+  { ER_SP_NO_AGGREGATE                      ,"42000", "" },
+  { ER_MAX_PREPARED_STMT_COUNT_REACHED      ,"42000", "" },
+  { ER_NON_GROUPING_FIELD_USED              ,"42000", "" },
+  { ER_FOREIGN_DUPLICATE_KEY                ,"23000", "S1009" },
+  { ER_CANT_CHANGE_TX_ISOLATION             ,"25001", "" },
+  { ER_WRONG_PARAMCOUNT_TO_NATIVE_FCT       ,"42000", "" },
+  { ER_WRONG_PARAMETERS_TO_NATIVE_FCT       ,"42000", "" },
+  { ER_WRONG_PARAMETERS_TO_STORED_FCT       ,"42000", "" },
+  { ER_DUP_ENTRY_WITH_KEY_NAME              ,"23000", "S1009" },
+};
+
+#endif

=== modified file 'drizzled/unireg.h'
--- drizzled/unireg.h	2008-07-30 06:09:57 +0000
+++ drizzled/unireg.h	2008-07-30 18:03:54 +0000
@@ -225,7 +225,7 @@
 
 /* Include prototypes for unireg */
 
-#include <include/drizzled_error.h>
+#include <drizzled/error.h>
 #include "structs.h"				/* All structs we need */
 
 #endif

=== removed directory 'include'
=== removed file 'include/Makefile.am'
--- include/Makefile.am	2008-07-30 06:09:57 +0000
+++ include/Makefile.am	1970-01-01 00:00:00 +0000
@@ -1,68 +0,0 @@
-# Copyright (C) 2000-2006 MySQL AB
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
-# License as published by the Free Software Foundation; version 2
-# of the License.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
-#
-# You should have received a copy of the GNU Library General Public
-# License along with this library; if not, write to the Free
-# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-# MA 02111-1307, USA
-
-
-BUILT_SOURCES =		drizzled_ername.h \
-			drizzled_error.h \
-			sql_state.h
-
-pkginclude_HEADERS =	$(BUILT_SOURCES)
-
-LDADD = $(top_builddir)/mysys/libmysyslt.la \
-        $(top_builddir)/mystrings/libmystringslt.la $(ZLIB_LIBS)
-
-EXTRA_PROGRAMS = comp_err
-comperr_CFLAGS = -I${top_srcdir}/drizzled
-
-# This will build drizzled_error.h, drizzled_ername.h and sql_state.h
-# NOTE Built files should depend on their sources to avoid
-# the built files being rebuilt in source dist
-drizzled_error.h: comp_err$(EXEEXT) $(top_srcdir)/drizzled/share/errmsg.txt
-	$(top_builddir)/include/comp_err$(EXEEXT) \
-	--charset=$(top_srcdir)/drizzled/share/charsets \
-	--out-dir=$(top_builddir)/drizzled/share/ \
-	--header_file=$(top_builddir)/include/drizzled_error.h \
-	--name_file=$(top_builddir)/include/drizzled_ername.h \
-	--state_file=$(top_builddir)/include/sql_state.h \
-	--in_file=$(top_srcdir)/drizzled/share/errmsg.txt
-
-drizzled_ername.h: drizzled_error.h
-sql_state.h: drizzled_error.h
-
-# Remove built files and the symlinked directories
-CLEANFILES = 		$(BUILT_SOURCES)
-
-EXTRA_DIST = 		drizzle_h.ic
-
-# Some include files that may be moved and patched by configure
-DISTCLEANFILES =	sched.h \
-			$(CLEANFILES)
-
-
-#
-# Rules for checking that ABI has not changed
-#
-
-# Create a icheck file and compare it to the reference
-abi_check:	$(HEADERS_ABI) drizzle_version.h mysql_h.ic
-	@set -ex; \
-	if test "x@ICHECK@" != "xno"  ; then \
-		@ICHECK@ --canonify --skip-from-re /usr/ -o $@ $(HEADERS_ABI); \
-		@ICHECK@ --compare drizzle_h.ic $@; \
-	fi; \
-	touch abi_check;
-

=== removed file 'include/comp_err.c'
--- include/comp_err.c	2008-07-30 05:33:20 +0000
+++ include/comp_err.c	1970-01-01 00:00:00 +0000
@@ -1,1022 +0,0 @@
-/* Copyright (C) 2004 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-/*
-  Written by Anjuta Widenius
-*/
-
-/*
-  Creates one include file and multiple language-error message files from one
-  multi-language text file.
-*/
-
-#include <drizzled/global.h>
-#include <mystrings/m_ctype.h>
-#include <mysys/my_sys.h>
-#include <mystrings/m_string.h>
-#include <mysys/my_getopt.h>
-#include <assert.h>
-
-#define MAX_ROWS  1000
-#define HEADER_LENGTH 32                /* Length of header in errmsg.sys */
-#define DEFAULT_CHARSET_DIR "../sql/share/charsets"
-#define ER_PREFIX "ER_"
-#define WARN_PREFIX "WARN_"
-static char *OUTFILE= (char*) "errmsg.sys";
-static char *HEADERFILE= (char*) "drizzled_error.h";
-static char *NAMEFILE= (char*) "drizzled_ername.h";
-static char *STATEFILE= (char*) "sql_state.h";
-static char *TXTFILE= (char*) "../sql/share/errmsg.txt";
-static char *DATADIRECTORY= (char*) "../sql/share/";
-
-/* Header for errmsg.sys files */
-uchar file_head[]= { 254, 254, 2, 1 };
-/* Store positions to each error message row to store in errmsg.sys header */
-uint file_pos[MAX_ROWS];
-
-const char *empty_string= "";			/* For empty states */
-/*
-  Default values for command line options. See getopt structure for definitions
-  for these.
-*/
-
-const char *default_language= "eng";
-int er_offset= 1000;
-my_bool info_flag= 0;
-
-/* Storage of one error message row (for one language) */
-
-struct message
-{
-  char *lang_short_name;
-  char *text;
-};
-
-
-/* Storage for languages and charsets (from start of error text file) */
-
-struct languages
-{
-  char *lang_long_name;				/* full name of the language */
-  char *lang_short_name;			/* abbreviation of the lang. */
-  char *charset;				/* Character set name */
-  struct languages *next_lang;			/* Pointer to next language */
-};
-
-
-/* Name, code and  texts (for all lang) for one error message */
-
-struct errors
-{
-  const char *er_name;			/* Name of the error (ER_HASHCK) */
-  int d_code;                           /* Error code number */
-  const char *sql_code1;		/* sql state */
-  const char *sql_code2;		/* ODBC state */
-  struct errors *next_error;            /* Pointer to next error */
-  DYNAMIC_ARRAY msg;                    /* All language texts for this error */
-};
-
-
-static struct my_option my_long_options[]=
-{
-  {"debug-info", 'T', "Print some debug info at exit.", (char**) & info_flag,
-   (char**) & info_flag, 0, GET_BOOL, NO_ARG, 0, 0, 0, 0, 0, 0},
-  {"help", '?', "Displays this help and exits.", 0, 0, 0, GET_NO_ARG,
-   NO_ARG, 0, 0, 0, 0, 0, 0},
-  {"version", 'V', "Prints version", 0, 0, 0, GET_NO_ARG,
-   NO_ARG, 0, 0, 0, 0, 0, 0},
-  {"charset", 'C', "Charset dir", (char**) & charsets_dir,
-   (char**) & charsets_dir,
-   0, GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {"in_file", 'F', "Input file", (char**) & TXTFILE, (char**) & TXTFILE,
-   0, GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {"out_dir", 'D', "Output base directory", (char**) & DATADIRECTORY,
-   (char**) & DATADIRECTORY,
-   0, GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {"out_file", 'O', "Output filename (errmsg.sys)", (char**) & OUTFILE,
-   (char**) & OUTFILE, 0, GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {"header_file", 'H', "drizzled_error.h file ", (char**) & HEADERFILE,
-   (char**) & HEADERFILE, 0, GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {"name_file", 'N', "drizzled_ername.h file ", (char**) & NAMEFILE,
-   (char**) & NAMEFILE, 0, GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {"state_file", 'S', "sql_state.h file", (char**) & STATEFILE,
-   (char**) & STATEFILE, 0, GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
-  {0, 0, 0, 0, 0, 0, GET_NO_ARG, NO_ARG, 0, 0, 0, 0, 0, 0}
-};
-
-
-static struct languages *parse_charset_string(char *str);
-static struct errors *parse_error_string(char *ptr, int er_count);
-static struct message *parse_message_string(struct message *new_message,
-					    char *str);
-static struct message *find_message(struct errors *err, const char *lang,
-                                    my_bool no_default);
-static int check_message_format(struct errors *err,
-                                const char* mess);
-static int parse_input_file(const char *file_name, struct errors **top_error,
-			    struct languages **top_language);
-static int get_options(int *argc, char ***argv);
-static void print_version(void);
-static void usage(void);
-static bool get_one_option(int optid, const struct my_option *opt,
-			      char *argument);
-static char *parse_text_line(char *pos);
-static int copy_rows(FILE * to, char *row, int row_nr, long start_pos);
-static char *parse_default_language(char *str);
-static uint parse_error_offset(char *str);
-
-static char *skip_delimiters(char *str);
-static char *get_word(char **str);
-static char *find_end_of_word(char *str);
-static void clean_up(struct languages *lang_head, struct errors *error_head);
-static int create_header_files(struct errors *error_head);
-static int create_sys_files(struct languages *lang_head,
-			    struct errors *error_head, uint row_count);
-
-
-int main(int argc, char *argv[])
-{
-  MY_INIT(argv[0]);
-  {
-    uint row_count;
-    struct errors *error_head;
-    struct languages *lang_head;
-
-    charsets_dir= DEFAULT_CHARSET_DIR;
-    my_umask_dir= 0777;
-    if (get_options(&argc, &argv))
-      return(1);
-    if (!(row_count= parse_input_file(TXTFILE, &error_head, &lang_head)))
-    {
-      fprintf(stderr, "Failed to parse input file %s\n", TXTFILE);
-      return(1);
-    }
-    if (lang_head == NULL || error_head == NULL)
-    {
-      fprintf(stderr, "Failed to parse input file %s\n", TXTFILE);
-      return(1);
-    }
-
-    if (create_header_files(error_head))
-    {
-      fprintf(stderr, "Failed to create header files\n");
-      return(1);
-    }
-    if (create_sys_files(lang_head, error_head, row_count))
-    {
-      fprintf(stderr, "Failed to create sys files\n");
-      return(1);
-    }
-    clean_up(lang_head, error_head);
-    my_end(info_flag ? MY_CHECK_ERROR | MY_GIVE_INFO : 0);
-    return 0;
-  }
-}
-
-
-static int create_header_files(struct errors *error_head)
-{
-  uint er_last;
-  FILE *er_definef, *sql_statef, *er_namef;
-  struct errors *tmp_error;
-
-  if (!(er_definef= my_fopen(HEADERFILE, O_WRONLY, MYF(MY_WME))))
-  {
-    return(1);
-  }
-  if (!(sql_statef= my_fopen(STATEFILE, O_WRONLY, MYF(MY_WME))))
-  {
-    my_fclose(er_definef, MYF(0));
-    return(1);
-  }
-  if (!(er_namef= my_fopen(NAMEFILE, O_WRONLY, MYF(MY_WME))))
-  {
-    my_fclose(er_definef, MYF(0));
-    my_fclose(sql_statef, MYF(0));
-    return(1);
-  }
-
-  fprintf(er_definef, "/* Autogenerated file, please don't edit */\n\n");
-  fprintf(sql_statef, "/* Autogenerated file, please don't edit */\n\n");
-  fprintf(er_namef, "/* Autogenerated file, please don't edit */\n\n");
-
-  fprintf(er_definef, "#define ER_ERROR_FIRST %d\n", error_head->d_code);
-
-  for (tmp_error= error_head; tmp_error; tmp_error= tmp_error->next_error)
-  {
-    /*
-       generating drizzled_error.h
-       fprintf() will automatically add \r on windows
-    */
-    fprintf(er_definef, "#define %s %d\n", tmp_error->er_name,
-	    tmp_error->d_code);
-    er_last= tmp_error->d_code;
-
-    /* generating sql_state.h file */
-    if (tmp_error->sql_code1[0] || tmp_error->sql_code2[0])
-      fprintf(sql_statef,
-	      "{ %-40s,\"%s\", \"%s\" },\n", tmp_error->er_name,
-	      tmp_error->sql_code1, tmp_error->sql_code2);
-    /*generating er_name file */
-    fprintf(er_namef, "{ \"%s\", %d },\n", tmp_error->er_name,
-	    tmp_error->d_code);
-
-  }
-  /* finishing off with drizzled_error.h */
-  fprintf(er_definef, "#define ER_ERROR_LAST %d\n", er_last);
-  my_fclose(er_definef, MYF(0));
-  my_fclose(sql_statef, MYF(0));
-  my_fclose(er_namef, MYF(0));
-  return(0);
-}
-
-
-static int create_sys_files(struct languages *lang_head,
-			    struct errors *error_head, uint row_count)
-{
-  FILE *to;
-  uint csnum= 0, length, i, row_nr;
-  uchar head[32];
-  char outfile[FN_REFLEN], *outfile_end;
-  long start_pos;
-  struct message *tmp;
-  struct languages *tmp_lang;
-  struct errors *tmp_error;
-
-  struct stat stat_info;
-
-  /*
-     going over all languages and assembling corresponding error messages
-  */
-  for (tmp_lang= lang_head; tmp_lang; tmp_lang= tmp_lang->next_lang)
-  {
-
-    /* setting charset name */
-    if (!(csnum= get_charset_number(tmp_lang->charset, MY_CS_PRIMARY)))
-    {
-      fprintf(stderr, "Unknown charset '%s' in '%s'\n", tmp_lang->charset,
-	      TXTFILE);
-      return(1);
-    }
-
-    outfile_end= strxmov(outfile, DATADIRECTORY, 
-                         tmp_lang->lang_long_name, NullS);
-    if (stat(outfile, &stat_info))
-    {
-      if (my_mkdir(outfile, 0777,MYF(0)) < 0)
-      {
-        fprintf(stderr, "Can't create output directory for %s\n", 
-                outfile);
-        return(1);
-      }
-    }
-
-    strxmov(outfile_end, FN_ROOTDIR, OUTFILE, NullS);
-
-    if (!(to= my_fopen(outfile, O_WRONLY | FILE_BINARY, MYF(MY_WME))))
-      return(1);
-
-    /* 2 is for 2 bytes to store row position / error message */
-    start_pos= (long) (HEADER_LENGTH + row_count * 2);
-    fseek(to, start_pos, 0);
-    row_nr= 0;
-    for (tmp_error= error_head; tmp_error; tmp_error= tmp_error->next_error)
-    {
-      /* dealing with messages */
-      tmp= find_message(tmp_error, tmp_lang->lang_short_name, false);
-
-      if (!tmp)
-      {
-	fprintf(stderr,
-		"Did not find message for %s neither in %s nor in default "
-		"language\n", tmp_error->er_name, tmp_lang->lang_short_name);
-	goto err;
-      }
-      if (copy_rows(to, tmp->text, row_nr, start_pos))
-      {
-	fprintf(stderr, "Failed to copy rows to %s\n", outfile);
-	goto err;
-      }
-      row_nr++;
-    }
-
-    /* continue with header of the errmsg.sys file */
-    length= ftell(to) - HEADER_LENGTH - row_count * 2;
-    memset((uchar*) head, 0, HEADER_LENGTH);
-    bmove((uchar *) head, (uchar *) file_head, 4);
-    head[4]= 1;
-    int2store(head + 6, length);
-    int2store(head + 8, row_count);
-    head[30]= csnum;
-
-    my_fseek(to, 0l, MY_SEEK_SET, MYF(0));
-    if (my_fwrite(to, (uchar*) head, HEADER_LENGTH, MYF(MY_WME | MY_FNABP)))
-      goto err;
-
-    for (i= 0; i < row_count; i++)
-    {
-      int2store(head, file_pos[i]);
-      if (my_fwrite(to, (uchar*) head, 2, MYF(MY_WME | MY_FNABP)))
-	goto err;
-    }
-    my_fclose(to, MYF(0));
-  }
-  return(0);
-
-err:
-  my_fclose(to, MYF(0));
-  return(1);
-}
-
-
-static void clean_up(struct languages *lang_head, struct errors *error_head)
-{
-  struct languages *tmp_lang, *next_language;
-  struct errors *tmp_error, *next_error;
-  uint count, i;
-
-  my_free((uchar*) default_language, MYF(0));
-
-  for (tmp_lang= lang_head; tmp_lang; tmp_lang= next_language)
-  {
-    next_language= tmp_lang->next_lang;
-    my_free(tmp_lang->lang_short_name, MYF(0));
-    my_free(tmp_lang->lang_long_name, MYF(0));
-    my_free(tmp_lang->charset, MYF(0));
-    my_free((uchar*) tmp_lang, MYF(0));
-  }
-
-  for (tmp_error= error_head; tmp_error; tmp_error= next_error)
-  {
-    next_error= tmp_error->next_error;
-    count= (tmp_error->msg).elements;
-    for (i= 0; i < count; i++)
-    {
-      struct message *tmp;
-      tmp= dynamic_element(&tmp_error->msg, i, struct message*);
-      my_free((uchar*) tmp->lang_short_name, MYF(0));
-      my_free((uchar*) tmp->text, MYF(0));
-    }
-
-    delete_dynamic(&tmp_error->msg);
-    if (tmp_error->sql_code1[0])
-      my_free((uchar*) tmp_error->sql_code1, MYF(0));
-    if (tmp_error->sql_code2[0])
-      my_free((uchar*) tmp_error->sql_code2, MYF(0));
-    my_free((uchar*) tmp_error->er_name, MYF(0));
-    my_free((uchar*) tmp_error, MYF(0));
-  }
-}
-
-
-static int parse_input_file(const char *file_name, struct errors **top_error,
-			    struct languages **top_lang)
-{
-  FILE *file;
-  char *str, buff[1000];
-  struct errors *current_error= 0, **tail_error= top_error;
-  struct message current_message;
-  int rcount= 0;
-
-  *top_error= 0;
-  *top_lang= 0;
-  if (!(file= my_fopen(file_name, O_RDONLY | O_SHARE, MYF(MY_WME))))
-    return(0);
-
-  while ((str= fgets(buff, sizeof(buff), file)))
-  {
-    if (is_prefix(str, "language"))
-    {
-      if (!(*top_lang= parse_charset_string(str)))
-      {
-	fprintf(stderr, "Failed to parse the charset string!\n");
-	return(0);
-      }
-      continue;
-    }
-    if (is_prefix(str, "start-error-number"))
-    {
-      if (!(er_offset= parse_error_offset(str)))
-      {
-	fprintf(stderr, "Failed to parse the error offset string!\n");
-	return(0);
-      }
-      continue;
-    }
-    if (is_prefix(str, "default-language"))
-    {
-      if (!(default_language= parse_default_language(str)))
-      {
-	fprintf(stderr,
-		"Failed to parse the default language line. Aborting\n");
-	return(0);
-      }
-      continue;
-    }
-
-    if (*str == '\t' || *str == ' ')
-    {
-      /* New error message in another language for previous error */
-      if (!current_error)
-      {
-	fprintf(stderr, "Error in the input file format\n");
-	return(0);
-      }
-      if (!parse_message_string(&current_message, str))
-      {
-	fprintf(stderr, "Failed to parse message string for error '%s'",
-		current_error->er_name);
-	return(0);
-      }
-      if (find_message(current_error, current_message.lang_short_name, true))
-      {
-	fprintf(stderr, "Duplicate message string for error '%s'"
-                        " in language '%s'\n",
-		current_error->er_name, current_message.lang_short_name);
-	return(0);
-      }
-      if (check_message_format(current_error, current_message.text))
-      {
-	fprintf(stderr, "Wrong formatspecifier of error message string"
-                        " for error '%s' in language '%s'\n",
-		current_error->er_name, current_message.lang_short_name);
-	return(0);
-      }
-      if (insert_dynamic(&current_error->msg, (uchar *) & current_message))
-	return(0);
-      continue;
-    }
-    if (is_prefix(str, ER_PREFIX) || is_prefix(str, WARN_PREFIX))
-    {
-      if (!(current_error= parse_error_string(str, rcount)))
-      {
-	fprintf(stderr, "Failed to parse the error name string\n");
-	return(0);
-      }
-      rcount++;                         /* Count number of unique errors */
-
-      /* add error to the list */
-      *tail_error= current_error;
-      tail_error= &current_error->next_error;
-      continue;
-    }
-    if (*str == '#' || *str == '\n')
-      continue;					/* skip comment or empty lines */
-
-    fprintf(stderr, "Wrong input file format. Stop!\nLine: %s\n", str);
-    return(0);
-  }
-  *tail_error= 0;				/* Mark end of list */
-
-  my_fclose(file, MYF(0));
-  return(rcount);
-}
-
-
-static uint parse_error_offset(char *str)
-{
-  char *soffset, *end;
-  int error;
-  uint ioffset;
-
-  /* skipping the "start-error-number" keyword and spaces after it */
-  str= find_end_of_word(str);
-  str= skip_delimiters(str);
-
-  if (!*str)
-    return(0);     /* Unexpected EOL: No error number after the keyword */
-
-  /* reading the error offset */
-  if (!(soffset= get_word(&str)))
-    return(0);				/* OOM: Fatal error */
-
-  /* skipping space(s) and/or tabs after the error offset */
-  str= skip_delimiters(str);
-  if (*str)
-  {
-    /* The line does not end with the error offset -> error! */
-    fprintf(stderr, "The error offset line does not end with an error offset");
-    return(0);
-  }
-
-  end= 0;
-  ioffset= (uint) my_strtoll10(soffset, &end, &error);
-  my_free((uchar*) soffset, MYF(0));
-  return(ioffset);
-}
-
-
-/* Parsing of the default language line. e.g. "default-language eng" */
-
-static char *parse_default_language(char *str)
-{
-  char *slang;
-
-  /* skipping the "default-language" keyword */
-  str= find_end_of_word(str);
-  /* skipping space(s) and/or tabs after the keyword */
-  str= skip_delimiters(str);
-  if (!*str)
-  {
-    fprintf(stderr,
-	    "Unexpected EOL: No short language name after the keyword\n");
-    return(0);
-  }
-
-  /* reading the short language tag */
-  if (!(slang= get_word(&str)))
-    return(0);				/* OOM: Fatal error */
-
-  str= skip_delimiters(str);
-  if (*str)
-  {
-    fprintf(stderr,
-	    "The default language line does not end with short language "
-	    "name\n");
-    return(0);
-  }
-  return(slang);
-}
-
-
-/*
-  Find the message in a particular language
-
-  SYNOPSIS
-    find_message()
-    err             Error to find message for
-    lang            Language of message to find
-    no_default      Don't return default (English) if does not exit
-
-  RETURN VALUE
-    Returns the message structure if one is found, or NULL if not.
-*/
-static struct message *find_message(struct errors *err, const char *lang,
-                                    my_bool no_default)
-{
-  struct message *tmp, *return_val= 0;
-  uint i, count;
-
-  count= (err->msg).elements;
-  for (i= 0; i < count; i++)
-  {
-    tmp= dynamic_element(&err->msg, i, struct message*);
-
-    if (!strcmp(tmp->lang_short_name, lang))
-      return(tmp);
-    if (!strcmp(tmp->lang_short_name, default_language))
-    {
-      assert(tmp->text[0] != 0);
-      return_val= tmp;
-    }
-  }
-  return(no_default ? NULL : return_val);
-}
-
-
-
-/*
-  Check message format specifiers against error message for
-  previous language
-
-  SYNOPSIS
-    checksum_format_specifier()
-    msg            String for which to generate checksum
-                   for the format specifiers
-
-  RETURN VALUE
-    Returns the checksum for all the characters of the
-    format specifiers
-
-    Ex.
-     "text '%-64.s' text part 2 %d'"
-            ^^^^^^              ^^
-            characters will be xored to form checksum
-
-    NOTE:
-      Does not support format specifiers with positional args
-      like "%2$s" 
-*/
-
-static ha_checksum checksum_format_specifier(const char* msg)
-{
-  ha_checksum chksum= 0;
-  const uchar* p= (uchar *)msg;
-  const uchar* start= 0;
-  int num_format_specifiers= 0;
-  while (*p)
-  {
-
-    if (*p == '%')
-    {
-      start= p+1; /* Entering format specifier */
-      num_format_specifiers++;
-    }
-    else if (start)
-    {
-      switch(*p)
-      {
-      case 'd':
-      case 'u':
-      case 'x':
-      case 's':
-        chksum= my_checksum(chksum, start, p-start);
-        start= 0; /* Not in format specifier anymore */
-        break;
-
-      default:
-        break;
-      }
-    }
-
-    p++;
-  }
-
-  if (start)
-  {
-    /* Still inside a format specifier after end of string */
-
-    fprintf(stderr, "Still inside formatspecifier after end of string"
-                    " in'%s'\n", msg);
-    assert(start==0);
-  }
-
-  /* Add number of format specifiers to checksum as extra safeguard */
-  chksum+= num_format_specifiers;
-
-  return chksum;
-}
-
-
-/*
-  Check message format specifiers against error message for
-  previous language
-
-  SYNOPSIS
-    check_message_format()
-    err             Error to check message for
-    mess            Message to check
-
-  RETURN VALUE
-    Returns 0 if no previous error message or message format is ok
-*/
-static int check_message_format(struct errors *err,
-                                const char* mess)
-{
-  struct message *first;
-
-  /*  Get first message(if any) */
-  if ((err->msg).elements == 0)
-    return(0); /* No previous message to compare against */
-
-  first= dynamic_element(&err->msg, 0, struct message*);
-  assert(first != NULL);
-
-  if (checksum_format_specifier(first->text) !=
-      checksum_format_specifier(mess))
-  {
-    /* Check sum of format specifiers failed, they should be equal */
-    return(1);
-  }
-  return(0);
-}
-
-
-/*
-  Skips spaces and or tabs till the beginning of the next word
-  Returns pointer to the beginning of the first character of the word
-*/
-
-static char *skip_delimiters(char *str)
-{
-  for (;
-       *str == ' ' || *str == ',' || *str == '\t' || *str == '\r' ||
-       *str == '\n' || *str == '='; str++)
-    ;
-  return(str);
-}
-
-
-/*
-  Skips all characters till meets with space, or tab, or EOL
-*/
-
-static char *find_end_of_word(char *str)
-{
-  for (;
-       *str != ' ' && *str != '\t' && *str != '\n' && *str != '\r' && *str &&
-       *str != ',' && *str != ';' && *str != '='; str++)
-    ;
-  return(str);
-}
-
-
-/* Read the word starting from *str */
-
-static char *get_word(char **str)
-{
-  char *start= *str;
-
-  *str= find_end_of_word(start);
-  return(my_strndup(start, (uint) (*str - start),
-				    MYF(MY_WME | MY_FAE)));
-}
-
-
-/*
-  Parsing the string with short_lang - message text. Code - to
-  remember to which error does the text belong
-*/
-
-static struct message *parse_message_string(struct message *new_message,
-					    char *str)
-{
-  char *start;
-
-  /*skip space(s) and/or tabs in the beginning */
-  while (*str == ' ' || *str == '\t' || *str == '\n')
-    str++;
-
-  if (!*str)
-  {
-    /* It was not a message line, but an empty line. */
-    return(0);
-  }
-
-  /* reading the short lang */
-  start= str;
-  while (*str != ' ' && *str != '\t' && *str)
-    str++;
-  if (!(new_message->lang_short_name=
-	my_strndup(start, (uint) (str - start),
-			      MYF(MY_WME | MY_FAE))))
-    return(0);				/* Fatal error */
-
-  /*skip space(s) and/or tabs after the lang */
-  while (*str == ' ' || *str == '\t' || *str == '\n')
-    str++;
-
-  if (*str != '"')
-  {
-    fprintf(stderr, "Unexpected EOL");
-    return(0);
-  }
-
-  /* reading the text */
-  start= str + 1;
-  str= parse_text_line(start);
-
-  if (!(new_message->text= my_strndup(start, (uint) (str - start),
-						 MYF(MY_WME | MY_FAE))))
-    return(0);				/* Fatal error */
-
-  return(new_message);
-}
-
-
-/*
-  Parsing the string with error name and codes; returns the pointer to
-  the errors struct
-*/
-
-static struct errors *parse_error_string(char *str, int er_count)
-{
-  struct errors *new_error;
-  char *start;
-
-  /* create a new element */
-  new_error= (struct errors *) my_malloc(sizeof(*new_error), MYF(MY_WME));
-
-  if (my_init_dynamic_array(&new_error->msg, sizeof(struct message), 0, 0))
-    return(0);				/* OOM: Fatal error */
-
-  /* getting the error name */
-  start= str;
-  str= skip_delimiters(str);
-
-  if (!(new_error->er_name= get_word(&str)))
-    return(0);				/* OOM: Fatal error */
-
-  str= skip_delimiters(str);
-
-  /* getting the code1 */
-
-  new_error->d_code= er_offset + er_count;
-
-  str= skip_delimiters(str);
-
-  /* if we reached EOL => no more codes, but this can happen */
-  if (!*str)
-  {
-    new_error->sql_code1= empty_string;
-    new_error->sql_code2= empty_string;
-    return(new_error);
-  }
-
-  /* getting the sql_code 1 */
-
-  if (!(new_error->sql_code1= get_word(&str)))
-    return(0);				/* OOM: Fatal error */
-
-  str= skip_delimiters(str);
-
-  /* if we reached EOL => no more codes, but this can happen */
-  if (!*str)
-  {
-    new_error->sql_code2= empty_string;
-    return(new_error);
-  }
-
-  /* getting the sql_code 2 */
-  if (!(new_error->sql_code2= get_word(&str)))
-    return(0);				/* OOM: Fatal error */
-
-  str= skip_delimiters(str);
-  if (*str)
-  {
-    fprintf(stderr, "The error line did not end with sql/odbc code!");
-    return(0);
-  }
-
-  return(new_error);
-}
-
-
-/* 
-  Parsing the string with full lang name/short lang name/charset;
-  returns pointer to the language structure
-*/
-
-static struct languages *parse_charset_string(char *str)
-{
-  struct languages *head=0, *new_lang;
-
-  /* skip over keyword */
-  str= find_end_of_word(str);
-  if (!*str)
-  {
-    /* unexpected EOL */
-    return(0);
-  }
-
-  str= skip_delimiters(str);
-  if (!(*str != ';' && *str))
-    return(0);
-
-  do
-  {
-    /*creating new element of the linked list */
-    new_lang= (struct languages *) my_malloc(sizeof(*new_lang), MYF(MY_WME));
-    new_lang->next_lang= head;
-    head= new_lang;
-
-    /* get the full language name */
-
-    if (!(new_lang->lang_long_name= get_word(&str)))
-      return(0);				/* OOM: Fatal error */
-
-    /* getting the short name for language */
-    str= skip_delimiters(str);
-    if (!*str)
-      return(0);				/* Error: No space or tab */
-
-    if (!(new_lang->lang_short_name= get_word(&str)))
-      return(0);				/* OOM: Fatal error */
-
-    /* getting the charset name */
-    str= skip_delimiters(str);
-    if (!(new_lang->charset= get_word(&str)))
-      return(0);				/* Fatal error */
-
-    /* skipping space, tab or "," */
-    str= skip_delimiters(str);
-  }
-  while (*str != ';' && *str);
-
-  return(head);
-}
-
-
-/* Read options */
-
-static void print_version(void)
-{
-  printf("%s  (Compile errormessage)  Ver %s\n", my_progname, "2.0");
-  return;
-}
-
-
-static bool
-get_one_option(int optid, const struct my_option *opt __attribute__ ((unused)),
-	       char *argument __attribute__ ((unused)))
-{
-  switch (optid) {
-  case 'V':
-    print_version();
-    exit(0);
-    break;
-  case '?':
-    usage();
-    exit(0);
-    break;
-  }
-  return(0);
-}
-
-
-static void usage(void)
-{
-  print_version();
-  printf("This software comes with ABSOLUTELY NO WARRANTY. "
-         "This is free software,\n"
-         "and you are welcome to modify and redistribute it under the GPL license.\n"
-         "Usage:\n");
-  my_print_help(my_long_options);
-  my_print_variables(my_long_options);
-  return;
-}
-
-
-static int get_options(int *argc, char ***argv)
-{
-  int ho_error;
-
-  if ((ho_error= handle_options(argc, argv, my_long_options, get_one_option)))
-    return(ho_error);
-  return(0);
-}
-
-
-/*
-  Read rows and remember them until row that start with char Converts
-  row as a C-compiler would convert a textstring
-*/
-
-static char *parse_text_line(char *pos)
-{
-  int i, nr;
-  char *row= pos;
-
-  while (*pos)
-  {
-    if (*pos == '\\')
-    {
-      switch (*++pos) {
-      case '\\':
-      case '"':
-	VOID(strmov(pos - 1, pos));
-	break;
-      case 'n':
-	pos[-1]= '\n';
-	VOID(strmov(pos, pos + 1));
-	break;
-      default:
-	if (*pos >= '0' && *pos < '8')
-	{
-	  nr= 0;
-	  for (i= 0; i < 3 && (*pos >= '0' && *pos < '8'); i++)
-	    nr= nr * 8 + (*(pos++) - '0');
-	  pos -= i;
-	  pos[-1]= nr;
-	  VOID(strmov(pos, pos + i));
-	}
-	else if (*pos)
-	  VOID(strmov(pos - 1, pos));		/* Remove '\' */
-      }
-    }
-    else
-      pos++;
-  }
-  while (pos > row + 1 && *pos != '"')
-    pos--;
-  *pos= 0;
-  return(pos);
-}
-
-
-/* Copy rows from memory to file and remember position */
-
-static int copy_rows(FILE *to, char *row, int row_nr, long start_pos)
-{
-
-  file_pos[row_nr]= (int) (ftell(to) - start_pos);
-  if (fputs(row, to) == EOF || fputc('\0', to) == EOF)
-  {
-    fprintf(stderr, "Can't write to outputfile\n");
-    return(1);
-  }
-
-  return(0);
-}

=== modified file 'libdrizzle/client.c'
--- libdrizzle/client.c	2008-07-30 05:33:20 +0000
+++ libdrizzle/client.c	2008-07-30 18:03:54 +0000
@@ -53,7 +53,7 @@
 #include <mysys_err.h>
 #include <mystrings/m_string.h>
 #include <mystrings/m_ctype.h>
-#include "drizzled_error.h"
+#include <drizzled/error.h>
 #include "errmsg.h"
 #include <violite.h>
 #include <my_pthread.h>        /* because of signal()  */

=== modified file 'libdrizzle/drizzle.h'
--- libdrizzle/drizzle.h	2008-07-29 21:59:54 +0000
+++ libdrizzle/drizzle.h	2008-07-30 18:03:54 +0000
@@ -93,9 +93,6 @@
 
 #define DRIZZLE_COUNT_ERROR (~(uint64_t) 0)
 
-/* backward compatibility define - to be removed eventually */
-#define ER_WARN_DATA_TRUNCATED WARN_DATA_TRUNCATED
-
 typedef struct st_drizzle_rows {
   struct st_drizzle_rows *next;    /* list of rows */
   DRIZZLE_ROW data;

=== modified file 'libdrizzle/libdrizzle.c'
--- libdrizzle/libdrizzle.c	2008-07-30 05:33:20 +0000
+++ libdrizzle/libdrizzle.c	2008-07-30 18:03:54 +0000
@@ -24,7 +24,6 @@
 #include <mystrings/m_string.h>
 #include <mystrings/m_ctype.h>
 #include "drizzle.h"
-#include "drizzled_error.h"
 #include "errmsg.h"
 #include <violite.h>
 #include <sys/stat.h>

=== modified file 'libdrizzle/net_serv.c'
--- libdrizzle/net_serv.c	2008-07-30 05:33:20 +0000
+++ libdrizzle/net_serv.c	2008-07-30 18:03:54 +0000
@@ -19,7 +19,7 @@
  */
 #include <drizzled/global.h>
 #include <drizzle.h>
-#include <drizzled_error.h>
+#include <drizzled/error.h>
 #include <mysys/my_sys.h>
 #include <mystrings/m_string.h>
 #include <violite.h>

=== modified file 'storage/innobase/handler/ha_innodb.cc'
--- storage/innobase/handler/ha_innodb.cc	2008-07-29 07:47:38 +0000
+++ storage/innobase/handler/ha_innodb.cc	2008-07-30 18:03:54 +0000
@@ -30,7 +30,7 @@
 #endif
 
 #include <mysql_priv.h>
-#include <drizzled_error.h>
+#include <drizzled/error.h>
 
 #include <mystrings/m_ctype.h>
 #include <mysys/hash.h>

